%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   nls_step2.m -- estimate stochastic process
%   uses inaccurate estimates from nls_step1.m, for initial values

%   ALPHA-Z VERSION OF THE MODEL

%   moments to match: for 43 observations, 1963-2005
%   the entire covar matrix of the residuals from nls_step1.
%   there are four residual series, stacked

%   feed the model: skill abundance, time

%   estimate: three AR(1) processes and one iid variance
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all
clear global
close all
%clc

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
global data_w                   % skill premium
global data_hs data_hg          % skill intensitites
global data_p                   % relative price of services

load nls_alphaZ_step1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   TARGET VAR-COVAR MATRIX FROM STEP 1
v1 = w-data_w ;     v1=v1(2:end) ;
v2 = hs-data_hs ;   v2=v2(2:end) ;
v3 = hg-data_hg ;   v3=v3(2:end) ;
v4 = p-data_p ;     v4=v4(2:end) ;
%%% (above) drop first obs because p(1)=data_p(1) by construction
v = [v1;v2;v3;v4] ;
global var_v
var_v = v*v' ;  % target covar matrix
clear v1 v2 v3 v4 v
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   ESTIMATION OF AR(1) PROCESSES
%   last letter id: s=serv, g=goods, a=intersectoral, h=skill abundance

global T R
R = 100 ;        % number of simulations
T = length(w) ; % length of sample

%%% standard normal shocks
%%% these are the iid part of the AR(1) processes to be estimated
randn('state', 0);  % set seed to avoid unecessary noise
global ns ng na nh
ns = randn(T,R) ;
ng = randn(T,R) ;
na = randn(T,R) ;
nh = randn(T,R) ;

%%% initial values for AR(1) processes
%        correlations    stadard errors
%start =[rs0 rg0 ra0 sds0 sdg0 sda0 sdh0] ;
%start = [0.1 0.1 0.1 0.05 0.05 0.05 0.05] ;
start = [0.5 0.3 0.5 0.01 0.01 0.01 0.01] ;
%%% to keep search on (0,1). objective code takes y=exp{x}/(1+exp{x})
start(1:3) = log(start(1:3)) - log(1-start(1:3)) ;
%%% to keep search on >0. objective code takes exponent
start(4:7) = log(start(4:7)) ; 

options = optimset('Display','off') ;

tic
lb=[]; ub=[];
[estimates,fval,residuals,exitflag,output] = ...
    lsqnonlin(@nls_alphaZ_step2_objective_lsqnonlin,start,lb,ub,options) ;
toc
disp(output)
start(1:3) = exp(start(1:3))./(1+exp(start(1:3))) ;
start(4:7) = exp(start(4:7)) ;

%%% unpack estimates
estimates(1:3) = exp(estimates(1:3))./(1+exp(estimates(1:3))) ;
estimates(4:7) = exp(estimates(4:7)) ;
rs=estimates(1) ;
rg=estimates(2) ;
ra=estimates(3) ;
sds=estimates(4) ;
sdg=estimates(5) ;
sda=estimates(6) ;
sdh=estimates(7) ;
disp('estimates')
disp(estimates)
disp('fval')
disp(fval)
disp('exitflag')
disp(exitflag)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


save nls_alphaZ_step2
