function F=nls_step2_objective_fminunc(x)
%%% objective function for nl_step2.m
%%% last letter id: s=serv, g=goods, a=intersectoral, h=skill abundance

global data_w                   % skill premium
global data_hs data_hg          % skill intensitites
global data_p                   % relative price of services
global T R
global es eg beta0s beta1s beta0g beta1g
global ns ng na nh
global var_v

%   UNPACK ARGUMENT FOR SEARCH
x(1:4) = exp(x(1:4))./(1+exp(x(1:4))) ; % keep search on (0,1)
x(5:8) = exp(x(5:8)) ; % keep search >0
rs = x(1) ; % correlation coefficients
rg = x(2) ;
ra = x(3) ;
rh = x(4) ;
sds= x(5) ; % standard deviations
sdg= x(6) ;
sda= x(7) ;
sdh= x(8) ;

%   IID NORMAL SHOCKS ~ N(0,sd^2)
epss = sds*ns ;
epsg = sdg*ng ;
epsa = sda*na ;
epsh = sdh*nh ;

%   AR(1) PROCESSES: u(t) = r*u(t-1) + eps(t)
global us ug ua uh
us = zeros(T,R) ;
ug = zeros(T,R) ;
ua = zeros(T,R) ;
uh = zeros(T,R) ;
us(1,:) = epss(1,:) ;   % u(0)=E(u)=0 -> u(1)=eps(1)
ug(1,:) = epsg(1,:) ;
ua(1,:) = epsa(1,:) ;
uh(1,:) = epsh(1,:) ;
us(2:T,:) = rs*us(1:T-1,:) + epss(2:T,:) ;
ug(2:T,:) = rg*us(1:T-1,:) + epsg(2:T,:) ;
ua(2:T,:) = ra*us(1:T-1,:) + epsa(2:T,:) ;
uh(2:T,:) = rh*us(1:T-1,:) + epsh(2:T,:) ;

%   EQUILIBRIA AND ENDOGENOUS VARIABLES
w=zeros(T,R) ;
hs=zeros(T,R) ;
hg=zeros(T,R) ;
p=zeros(T,R) ;
v1=zeros(T,R) ;
v2=zeros(T,R) ;
v3=zeros(T,R) ;
v4=zeros(T,R) ;

options = optimset('Display','off') ;

global t r
for r=1:1:R  % simulations
    w0=1.5 ; % initial value for fsolve search
    w0=log(w0) ;
    for t=1:1:T % observations
        w(t,r)=fsolve(@nls_step2_equilibrium,w0,options) ;
        w0=w(t,r) ; % update initial value for efficiency in search
        w(t,r)=exp(w(t,r)) ;
        hs(t,r)=(w(t,r)^-es)*exp(beta0s+beta1s*(t-1)+us(t,r))^(es-1) ;
        hg(t,r)=(w(t,r)^-eg)*exp(beta0g+beta1g*(t-1)+ug(t,r))^(eg-1) ;
        p(t,r)=nls_step2_relprice(w(t,r)) ;   % relative price of S
    end
    p(:,r)=p(:,r)/p(1,r) ;	% normalize price=1 in 1963, as in data
    v1(:,r) = w(:,r)-data_w ;
    v2(:,r) = hs(:,r)-data_hs ;
    v3(:,r) = hg(:,r)-data_hg ;
    v4(:,r) = p(:,r)-data_p ;
end

%%% drop first obs because p(1)=data_p(1) by construction
v1=v1(2:T,:) ;
v2=v2(2:T,:) ;
v3=v3(2:T,:) ;
v4=v4(2:T,:) ;
%%% first covar matrix
v = [v1(:,1) ; v2(:,1) ; v3(:,1) ; v4(:,1)] ;
var_v_sim = v*v' ;  % target covar matrix
for r=2:1:R % compute average covar matrix over simulations
    v = [v1(:,r) ; v2(:,r) ; v3(:,r) ; v4(:,r)] ;
    var_v_1 = v*v' ;
    var_v_sim = (r-1)/r*var_v_sim + var_v_1/r ;
end
clear v1 v2 v3 v4 v var_v_1

var_v=reshape(var_v,[],1) ;
var_v_sim=reshape(var_v_sim,[],1) ;

%%% lsqnonlin minimizes sum{F.^2}
F = sum(sum((var_v-var_v_sim).^2)) ; 
