%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   smm3_analytical_agg_eos.m 

%   COMPUTE ANALYTICAL AGGREGATE ELASTICITY OF SUBSTITUTION
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function EOS = smm3_analytical_agg_eos(alpha,fi,es,eg,h,hs,hg,w)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   F is the implicit function that determines the equilibrium.
%   analytical aggregate EOS is given by (w*Fw)/(h*Fh), where Fw and Fh are
%   derivatives w.r.t. w and h.
%   w is the skill premium and h is skill abundance in the economy.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

m = (alpha/(1-alpha))^fi ;

Fw1 = eg*hg./(h-hg)./w ;
Fw2 = es*hs./(hs-h)./w ;
Fw3 = (fi-es).*hs./(1+w.*hs) ;
Fw4 = (eg-fi).*hg./(1+w.*hg) ;
Fw = m*(Fw1+Fw2+Fw3+Fw4) ;

Fh = - m*( (hs-hg)./(h-hg)./(hs-h) ) ;

EOS = - w.*Fw./h./Fh ;
