*************************************************************************
set more off 
capture log close
set logtype text
clear
set memory 750m

/************************************************************************
	Figure1_colprem_colsupply.do

	Figure 1: 	college premium and percent of college grads in labor force

	uses: 	cps6406countsample.do
			cps6406wagesample.do
************************************************************************/


* data generating do-files:
*do cps6406countsample.do
*do cps6406wagesample.do


****************************************************************************
*	AGGREGATE

clear
use wagesample6406exp5
merge year sex edu exp5 using countsample6406exp5, sort
tab _merge
list year sex edu exp if _merge==2
drop _merge

*	GENERATE FIXED N VECTOR OF HOURS WEIGHTS
egen N=mean(hrs), by(sex edu exp5)
label var N "Average hours share, by cell (time-fixed weights vector for wage aggregation)"

*	GENERATE ANNUAL WGAE INDEX N'W
gen NW=N*wksrwage
egen NWindex=sum(NW), by(year)
label var NWindex "Annual average real wage index"
label var NW "Real wage weighted by average hours (=N*wksrwage)"

*	GENERATE RELATIVE WAGES
gen relwksrwage=wksrwage/NWindex
label var relwksrwage "Relative weekly real wages"

*	GENERATE FIXED W VECTOR OF WAGES WEIGHTS
egen W=mean(relwksrwage), by(sex edu exp5)
label var W "Average wages by cell (time-fixed weights vector for hours aggregation)"

*	GENERATE LABOR SUPPLY IN RELATIVE EFFICIENCY UNITS
gen hrseff=hrs*W
egen hrseffpc=pc(hrseff), prop by(year)
drop hrseff
rename hrseffpc hrseff
label var hrseff "Fraction of total annual hours worked in relative efficiency units"

sort year sex edu exp5
save NWsample5, replace
clear
****************************************************************************


****************************************************************************
*	REGRESSIONS for COL and HS EQUIVALENTS
*	COLLEGE/HS PREMIUMS
*	CORRELATIONS AND STATISTICS

*	AGGREGATE

clear
use NWsample5
egen Nedu=sum(N), by(year edu)
gen w=NW/Nedu
collapse (sum) w, by(year edu)
reshape wide w, i(year) j(edu)

qui reg w1 w2 w4, noconst 
mat b=e(b)
local e1hsAGG=b[1,1]
local e1colAGG=b[1,2]
qui reg w3 w2 w4, noconst 
mat b=e(b)
local e3hsAGG=b[1,1]
local e3colAGG=b[1,2]

display `e1hsAGG'
display `e1colAGG'
display `e3hsAGG'
display `e3colAGG'

g px=w4/w2
save Figure1, replace
clear

use NWsample5
collapse (sum) hrs, by(year edu)
reshape wide hrs, i(year) j(edu)
g hs = hrs2 + (`e1hsAGG'*hrs1) + (`e3hsAGG'*hrs3)
g col = hrs4 + (`e1colAGG'*hrs1) + (`e3colAGG'*hrs3)
g x = col/hs

merge year using Figure1, sort
tab _merge
drop _merge
replace year=year+1900-1
g colprem=px-1
label var colprem "College Premium"
label var x "Relative Supply"
label var hrs4 "College Graduates"
compress
save Figure1, replace

/***
twoway (scatter colprem year, yaxis(1) c(l) ms(T) mc(cranberry) lc(cranberry) ///
	xtitle("") xlabel(1965(5)2005) legend(size(small)) scheme(s1color) ///
	ytitle("(College Wage/High-School Wage) - 1") ) ///
	(scatter x year, yaxis(2) c(l) ms(O) mc(green) lc(green) ///
	ytitle("College/High-School Equivalents", axis(2)) )
graph save    Figure1_college_equivalents, replace
graph export  Figure1_college_equivalents.wmf, as(wmf) replace
***/

twoway (scatter colprem year, yaxis(1) c(l) ms(T) mc(cranberry) lc(cranberry) ///
	xtitle("") xlabel(1965(5)2005) legend(size(small)) scheme(s1color) ///
	ytitle("(College Wage/High-School Wage) - 1") ) ///
	(scatter hrs4 year, yaxis(2) c(l) ms(O) mc(green) lc(green) ///
	ytitle("Share of College Graduates in Employment", axis(2)) )
graph save    Figure1_college_graduates, replace
graph export  Figure1_college_graduates.wmf, as(wmf) replace
graph export  Figure1_college_graduates.eps, as(eps) replace
*graph export  Figure1_college_graduates.tif, width(1200) replace

*************************************************************************

*/

erase NWsample5.dta
