set scheme s1color
set more off 
capture log close
set logtype text
clear
set memory 100m

/************************************************************************
	it_by_ind.do

IT share in capital stock by industry

use the following formula to get constant price values:
	k_co = q*k(2000)/100
- q is the chain-type quantity index, equal to 100 in 2000 and 
- k=Q*P, where Q is the quantity and P is the price in any given year.

	uses:	Capital_Stocks_by_ind_4706.csv
		Capital_Stocks_by_ind_4706_volumes.csv
		kid_ind_labels.do

data source: BEA, http://www.bea.gov/national/FA2004/Details/Index.html
************************************************************************/


*************************************************************************
*	load and clean k=Q*P

clear
insheet using Capital_Stocks_by_ind_4706.csv, names
reshape long k, i(name) j(year)
g indcode = substr(name,10,4)
g kcode = substr(name,-4,.)
drop name

do kid_ind_labels

keep if year==2000
rename k k2000
keep k2000 kid ind
sort ind kid
save k2000, replace
clear
*************************************************************************


*************************************************************************
*	load and clean q

clear
insheet using Capital_Stocks_by_ind_4706_volumes.csv, names
reshape long q, i(name) j(year)
g indcode = substr(name,10,4)
g kcode = substr(name,-4,.)
drop name

do kid_ind_labels

sort ind kid year
merge ind kid using k2000
tab _m
drop _m
g k=q*k2000/100
label var k "capital stocks in constant 2000 prices"
drop k2000 q
sort ind kid year
compress
save k, replace
clear
*************************************************************************



*************************************************************************
*	IT shares in TOTAL capital stock by industry

clear
use k
drop if kid==100 | kid==200
egen itsh=pc(k), prop by(ind year)
keep if kid>=101 & kid<=102
collapse (sum) itsh, by(ind year)
label var itsh "Computers and peripheral equipment, Software"
compress
sort ind year
save itsh_by_ind, replace


*	IT shares in TOTAL capital stock by sector

clear
use k
drop if kid==100 | kid==200
g byte sec=1+(ind>=40 & ind<=56 & ind~=53)
label var sec "1=Goods, 2=Serv"
collapse (sum) k, by(sec year kid)
egen itsh=pc(k), prop by(sec year)
keep if kid>=101 & kid<=102
collapse (sum) itsh, by(sec year)
label var itsh "Computers and peripheral equipment, Software"
compress
sort sec year
reshape wide itsh, i(year) j(sec)

label var itsh1 "Goods"
label var itsh2 "Services"
scatter itsh1 itsh2 year if year>=1960, c(l l) ms(i T) ///
	lc(cranberry navy) mc(cranberry navy) lw(medthick) ///
	xlabel(1960(5)2005) xt("") ylab(0(0.03)0.12) yt(IT Share)
graph export Figure3_itsh.wmf, as(wmf) replace
graph export Figure3_itsh.eps, as(eps) replace


/***


g rel_itsh=itsh2-itsh1
label var rel_itsh "Relative IT Share (Serv minus Goods)"
scatter rel_itsh year if year>=1960, c(l) ms(i) ///
	xlabel(1960(5)2005) xt("") 
graph export itsh_rel.wmf, as(wmf) replace

save itsh_by_sec, replace


*	IT expenditured by sector

clear
use k
drop if kid==100 | kid==200
g byte sec=1+(ind>=40 & ind<=56 & ind~=53)
label var sec "1=Goods, 2=Serv"
keep if kid>=101 & kid<=102
collapse (sum) k, by(sec year)
label var k "Computers and peripheral equipment, Software"
g lnk = log(k)
label var lnk "ln Computers and peripheral equipment, Software"
compress
sort sec year
reshape wide k ln, i(year) j(sec)

g dlnk = lnk2 - lnk1

label var lnk1 "Goods"
label var lnk2 "Services"
scatter lnk1 lnk2 year if year>=1960, ti(A. IT Capital Stock, size(meduim)) ///
	c(l l) ms(i T) lw(medthick) ///
	lc(cranberry navy) mc(cranberry navy) ///
	xlabel(1960(5)2005) xt("") /*ylab(0(0.03)0.12)*/ yt(Ln IT Capital)
graph export itk.wmf, as(wmf) replace
graph save   itk, replace

line dlnk year if year>=1960, ti(B. Difference in IT Capital Stocks, size(meduim)) ///
	lw(medthick) lc(navy) ///
	xlabel(1960(5)2005) xt("") /*ylab(0(0.03)0.12)*/ yt(Ln IT Capital in Services minus in Goods)
graph export itk_diff.wmf, as(wmf) replace
graph save   itk_diff, replace

graph combine itk.gph itk_diff.gph , rows(2) xsize(4) ysize(6)
*graph export itk_levels_diff.tif, width(1200) replace
