*************************************************************************
set more off 
capture log close
set logtype text
clear
set memory 150m

/************************************************************************
	data_for_RED_revision.do

	use aggregate equivalence weights to create college and HS
	equivalents -- for all industries

ind2 
1	Agriculture, forestry, & fisheries
2	Mining
3	Construction
4	Manufacturing, nondurable goods
5	Manufacturing, durable goods
6	Transportation (inc. USPS)
7	Communications & other public utilities
8	Wholesale trade
9	Retail trade
10	Finance, insurance & real estate
11	Business & repair services
12	Personal services
13	Entertainment & recreation services
14	Health services
15	Educational services
16	Other professional & related services

GOODS + LOW SKILL SERVICES: 	ind2<=9 
SERVICES: 				ind2>=10
************************************************************************/

/***

/* data generating do-files:
do $path\do\cps6406countsample.do
do $path\do\cps6406wagesample.do
do $path\do\cps6406countsample_manu.do
do $path\do\cps6406wagesample_manu.do
do $path\do\cps6406countsample_serv.do
do $path\do\cps6406wagesample_serv.do
do $path\do\cps6406countsample_goodserv.do
do $path\do\cps6406wagesample_goodserv.do
*/
*do ind2convert1990-2000countsample.do


****************************************************************************
*	AGGREGATE
*	not using industry classifications at all

use wagesample6406exp5, clear
merge year sex edu exp5 using countsample6406exp5, sort
tab _merge
list year sex edu exp if _merge==2
drop _merge

*	GENERATE FIXED N VECTOR OF HOURS WEIGHTS
egen N=mean(hrs), by(sex edu exp5)
label var N "Average hours share, by cell (time-fixed weights vector for wage aggregation)"

*	GENERATE ANNUAL WGAE INDEX N'W
gen NW=N*wksrwage
egen NWindex=sum(NW), by(year)
label var NWindex "Annual average real wage index"
label var NW "Real wage weighted by average hours (=N*wksrwage)"

*	GENERATE RELATIVE WAGES
gen relwksrwage=wksrwage/NWindex
label var relwksrwage "Relative weekly real wages"

*	GENERATE FIXED W VECTOR OF WAGES WEIGHTS
egen W=mean(relwksrwage), by(sex edu exp5)
label var W "Average wages by cell (time-fixed weights vector for hours aggregation)"

*	GENERATE LABOR SUPPLY IN RELATIVE EFFICIENCY UNITS
gen hrseff=hrs*W
egen hrseffpc=pc(hrseff), prop by(year)
drop hrseff
rename hrseffpc hrseff
label var hrseff "Fraction of total annual hours worked in relative efficiency units"
sort year sex edu exp5
save NWsample5, replace


*	REGRESSIONS for COL and HS EQUIVALENTS
*	COLLEGE/HS PREMIUMS

egen Nedu=sum(N), by(year edu)
gen w=NW/Nedu
collapse (sum) w, by(year edu)
reshape wide w, i(year) j(edu)

qui reg w1 w2 w4, noconst 
mat b=e(b)
local e1hs=b[1,1]
local e1col=b[1,2]
qui reg w3 w2 w4, noconst 
mat b=e(b)
local e3hs=b[1,1]
local e3col=b[1,2]

display `e1hs'
display `e1col'
display `e3hs'
display `e3col'

g e1hs  = `e1hs'
g e1col = `e1col'
g e3hs  = `e3hs'
g e3col = `e3col'

label var e1hs  "allocation of HS dropout hours to HS = `e1hs'"
label var e1col "allocation of HS dropout hours to college = `e1col'"
label var e3hs  "allocation of some-college hours to HS = `e3hs'"
label var e3col "allocation of some-college hours to college = `e3col'"

gen pxAG=w4/w2
sort year 
save pxAG, replace

use NWsample5, clear
collapse (sum) hrs, by(year edu)
reshape wide hrs, i(year) j(edu)
gen hsAG = hrs2 + (`e1hs'*hrs1) + (`e3hs'*hrs3)
gen colAG = hrs4 + (`e1col'*hrs1) + (`e3col'*hrs3)
gen xAG = colAG/hsAG
merge year using pxAG, sort
tab _merge
drop _merge

label var hrs1 "employment share of HS dropouts"
label var hrs2 "employment share of HS"
label var hrs3 "employment share of some college"
label var hrs4 "employment share of college"
label var w1 "weekly wage of HS dropouts"
label var w2 "weekly wage of HS"
label var w3 "weekly wage of some college"
label var w4 "weekly wage of college"

rename hrs1 hrs1AG
rename hrs2 hrs2AG
rename hrs3 hrs3AG
rename hrs4 hrs4AG
rename w1 w1AG
rename w2 w2AG
rename w3 w3AG
rename w4 w4AG
label var hsAG "employment share of HS-equivalents"
label var colAG "employment share of college-equivalents"
label var xAG "=colAG/hsAG, skill abundance"
label var pxAG "=w4/w2, relative wage of college to HS"

order y hrs* hs col x w* px
sort year
compress
save pxAG, replace

****************************************************************************



****************************************************************************
*	GOODS + LOW SKILL SERVICES

clear
use countsample6406ind2corrected
keep if ind2<=9
collapse (sum) hrs, by(year sex edu exp5)

merge year sex edu exp5 using wagesample6406exp5_goodserv, sort
tab _merge
list year sex edu exp if _merge==2
drop _merge

*	GENERATE FIXED N VECTOR OF HOURS WEIGHTS
egen N=mean(hrs), by(sex edu exp5)
label var N "Average hours share, by cell (time-fixed weights vector for wage aggregation)"

*	GENERATE ANNUAL WGAE INDEX N'W
gen NW=N*wksrwage
egen NWindex=sum(NW), by(year)
label var NWindex "Annual average real wage index"
label var NW "Real wage weighted by average hours (=N*wksrwage)"

*	GENERATE RELATIVE WAGES
gen relwksrwage=wksrwage/NWindex
label var relwksrwage "Relative weekly real wages"

*	GENERATE FIXED W VECTOR OF WAGES WEIGHTS
egen W=mean(relwksrwage), by(sex edu exp5)
label var W "Average wages by cell (time-fixed weights vector for hours aggregation)"

*	GENERATE LABOR SUPPLY IN RELATIVE EFFICIENCY UNITS
gen hrseff=hrs*W
egen hrseffpc=pc(hrseff), prop by(year)
drop hrseff
rename hrseffpc hrseff
label var hrseff "Fraction of total annual hours worked in relative efficiency units"

sort year sex edu exp5
save NWsample5goodserv, replace

*	college and HS equivalents

egen Nedu=sum(N), by(year edu)
gen w=NW/Nedu
collapse (sum) w, by(year edu)
reshape wide w, i(year) j(edu)

gen pxGS=w4/w2
sort year year
save pxGS, replace
clear

use NWsample5goodserv
collapse (sum) hrs, by(year edu)
reshape wide hrs, i(year) j(edu)
gen hsGS = hrs2 + (`e1hs'*hrs1) + (`e3hs'*hrs3)
gen colGS = hrs4 + (`e1col'*hrs1) + (`e3col'*hrs3)
gen xGS = colGS/hsGS

merge year using pxGS, sort
tab _merge
drop _merge

label var hrs1 "employment share of HS dropouts"
label var hrs2 "employment share of HS"
label var hrs3 "employment share of some college"
label var hrs4 "employment share of college"
label var w1 "weekly wage of HS dropouts"
label var w2 "weekly wage of HS"
label var w3 "weekly wage of some college"
label var w4 "weekly wage of college"

rename hrs1 hrs1GS
rename hrs2 hrs2GS
rename hrs3 hrs3GS
rename hrs4 hrs4GS
rename w1 w1GS
rename w2 w2GS
rename w3 w3GS
rename w4 w4GS
label var hsGS "employment share of HS-equivalents"
label var colGS "employment share of college-equivalents"
label var xGS "=colGS/hsGS, skill intensity"
label var pxGS "=w4/w2, relative wage of college to HS"

order y hrs* hs col x w* px
sort year
compress
save pxGS, replace

****************************************************************************



****************************************************************************
*	SERVICES

clear
use countsample6406ind2corrected
keep if ind2>=10
collapse (sum) hrs, by(year sex edu exp5)

merge year sex edu exp5 using wagesample6406exp5_serv, sort
tab _merge
list year sex edu exp if _merge==2
drop _merge

*	GENERATE FIXED N VECTOR OF HOURS WEIGHTS
egen N=mean(hrs), by(sex edu exp5)
label var N "Average hours share, by cell (time-fixed weights vector for wage aggregation)"

*	GENERATE ANNUAL WGAE INDEX N'W
gen NW=N*wksrwage
egen NWindex=sum(NW), by(year)
label var NWindex "Annual average real wage index"
label var NW "Real wage weighted by average hours (=N*wksrwage)"

*	GENERATE RELATIVE WAGES
gen relwksrwage=wksrwage/NWindex
label var relwksrwage "Relative weekly real wages"

*	GENERATE FIXED W VECTOR OF WAGES WEIGHTS
egen W=mean(relwksrwage), by(sex edu exp5)
label var W "Average wages by cell (time-fixed weights vector for hours aggregation)"

*	GENERATE LABOR SUPPLY IN RELATIVE EFFICIENCY UNITS
gen hrseff=hrs*W
egen hrseffpc=pc(hrseff), prop by(year)
drop hrseff
rename hrseffpc hrseff
label var hrseff "Fraction of total annual hours worked in relative efficiency units"

sort year sex edu exp5
save NWsample5serv, replace

*	college and HS equivalents

egen Nedu=sum(N), by(year edu)
gen w=NW/Nedu
collapse (sum) w, by(year edu)
reshape wide w, i(year) j(edu)

gen pxSV=w4/w2
sort year
save pxSV, replace
clear

use NWsample5serv
collapse (sum) hrs, by(year edu)
reshape wide hrs, i(year) j(edu)
gen hsSV = hrs2 + (`e1hs'*hrs1) + (`e3hs'*hrs3)
gen colSV = hrs4 + (`e1col'*hrs1) + (`e3col'*hrs3)
gen xSV = colSV/hsSV

merge year using pxSV, sort
tab _merge
drop _merge

label var hrs1 "employment share of HS dropouts"
label var hrs2 "employment share of HS"
label var hrs3 "employment share of some college"
label var hrs4 "employment share of college"
label var w1 "weekly wage of HS dropouts"
label var w2 "weekly wage of HS"
label var w3 "weekly wage of some college"
label var w4 "weekly wage of college"

rename hrs1 hrs1SV
rename hrs2 hrs2SV
rename hrs3 hrs3SV
rename hrs4 hrs4SV
rename w1 w1SV
rename w2 w2SV
rename w3 w3SV
rename w4 w4SV
label var hsSV "employment share of HS-equivalents"
label var colSV "employment share of college-equivalents"
label var xSV "=colSV/hsSV, skill intensity"
label var pxSV "=w4/w2, relative wage of college to HS"

order y hrs* hs col x w* px
sort year
compress
save pxSV, replace

****************************************************************************


*************************************************************************
*	MERGE

clear
use pxAG
merge year using pxSV pxGS, sort
erase pxAG.dta
erase pxSV.dta
erase pxGS.dta
sum _merge*
drop _merge*

erase NWsample5.dta
erase NWsample5serv.dta
erase NWsample5goodserv.dta


*** CORRECT EMPLOYMENT SHARES TO TAKE INTO ACCOUNT "EQUIVALENTS" CALCULATION

g nAG = hsAG + colAG
replace hsSV = hsSV/nAG
replace colSV = colSV/nAG
replace hsGS = hsGS/nAG
replace colGS = colGS/nAG
drop nAG

replace year = year + 1900 - 1
label var year "year"
sort year
save data_for_RED_revision, replace
*************************************************************************

***/

/***

*************************************************************************
***	FIGURES AND OUTPUTS

use data_for_RED_revision, clear

label var hsSV "HS"
label var colSV "College"
label var hsGS "HS"
label var colGS "College"

scatter colSV hsSV colGS hsGS year, c(l l l l) ms(T Th S Sh) ///
	/***yt(Employment Share of Labor Equivalents)***/ xt("") xlab(1965(5)2005) ///
	legend(rows(2) order(- "Services:" 1 2 - "Goods:" 3 4)) xsize(4) ysize(3)
graph export employment_shares.wmf, as(wmf) replace

label var w2SV "HS"
label var w4SV "College"
label var w2GS "HS"
label var w4GS "College"

scatter w4SV w2SV w4GS w2GS year, c(l l l l) ms(T Th S Sh) ///
	yt("Weekly Wage (2000 Prices)") xt("") xlab(1965(5)2005) ///
	legend(rows(2) order(- "Services:" 1 2 - "Goods:" 3 4)) xsize(4) ysize(3)
graph export wages.wmf, as(wmf) replace

label var w2SV "Services"
label var w4SV "Services"
label var w2GS "Goods"
label var w4GS "Goods"

scatter w2SV w2GS year, c(l l) ms(Th Sh) ti(B. High-School) ///
	lc(navy cranberry) mc(navy cranberry) ///
	/***yt("Weekly Wage (2000 Prices)")***/ xt("") xlab(1965(10)2005) ///
	legend(rows(1)) xsize(4) ysize(3)
graph export wages_HS.wmf, as(wmf) replace
graph save   wages_HS, replace

scatter w4SV w4GS year, c(l l) ms(T S) ti(A. College) ///
	lc(navy cranberry) mc(navy cranberry) ///
	yt("Weekly Wage (2000 Prices)") xt("") xlab(1965(10)2005) ///
	legend(rows(1)) xsize(4) ysize(3)
graph export wages_COL.wmf, as(wmf) replace
graph save   wages_COL, replace

graph combine wages_COL.gph wages_HS.gph
graph export wages2.wmf, as(wmf) replace

g w2GS_w2SV = w2GS/w2SV
g w4GS_w4SV = w4GS/w4SV
su w2GS_w2SV 
local m = round(r(mean),.01)
g m_w2GS_w2SV = `m'
label var w2GS_w2SV "High School"
label var m_w2GS_w2SV "HS Avg.=`m'"
label var w4GS_w4SV "College"
scatter w2GS_w2SV m_w2GS_w2SV w4GS_w4SV year, c(l l l) lp(l -- l) ms(Oh i T) ///
	lc(cranberry cranberry navy) mc(cranberry cranberry navy) ///
	yt(Wage in Goods/Wage in Services) xt("") xlab(1965(5)2005) ///
	legend(rows(1)) xsize(4) ysize(3) 
*yline(`m', lc(cranberry) lp(--))
graph export wages_goods_v_serv.wmf, as(wmf) replace

g cpAG = pxAG - 1 
g cpSV = pxSV - 1 
g cpGS = pxGS - 1 
label var cpAG "Aggregate"
label var cpSV "Services"
label var cpGS "Goods"
scatter cpGS cpSV year, c(l l) ms(i T) ///
	lc(cranberry navy) mc(cranberry navy) ///
	yt("(College Wage/High School Wage) - 1") xt("") xlab(1965(5)2005) ///
	legend(rows(1)) xsize(4) ysize(3)
graph export college_prem.wmf, as(wmf) replace

*************************************************************************

***/

*************************************************************************
***	REGRESSIONS FOR PAPER

use data_for_RED_revision, clear

sort year
g t=_n

foreach s in AG SV GS {
	g lx`s' = log(x`s')
	g lpx`s' = log(px`s')
}

tsset year

capture log using Table_3_data_for_RED_revision, replace

***	GOODS

reg lxGS lpxAG t
	outreg2 lpxAG t using Table_3_data_for_RED_revision, bdec(2) sdec(3) excel replace
estat bgodfrey
estat durbinalt
estat dwatson
display "rho_hat = " 1-(r(dw)/2)

reg lxGS lpxGS t
	outreg2 lpxGS t using Table_3_data_for_RED_revision, bdec(2) sdec(3) excel append
estat bgodfrey
estat durbinalt
estat dwatson
display "rho_hat = " 1-(r(dw)/2)

prais lxGS lpxAG t, two
	outreg2 lpxAG t using Table_3_data_for_RED_revision, bdec(2) sdec(3) excel append

prais lxGS lpxGS t, two
	outreg2 lpxGS t using Table_3_data_for_RED_revision, bdec(2) sdec(3) excel append

***	SERVICES

reg lxSV lpxAG t
	outreg2 lpxAG t using Table_3_data_for_RED_revision, bdec(2) sdec(3) excel append
estat bgodfrey
estat durbinalt
estat dwatson
display "rho_hat = " 1-(r(dw)/2)

reg lxSV lpxSV t
	outreg2 lpxSV t using Table_3_data_for_RED_revision, bdec(2) sdec(3) excel append
estat bgodfrey
estat durbinalt
estat dwatson
display "rho_hat = " 1-(r(dw)/2)

prais lxSV lpxAG t, two
	outreg2 lpxAG t using Table_3_data_for_RED_revision, bdec(2) sdec(3) excel append

prais lxSV lpxSV t, two
	outreg2 lpxSV t using Table_3_data_for_RED_revision, bdec(2) sdec(3) excel append

log close

*************************************************************************

