*************************************************************************
set more off 
capture log close
set logtype text
clear
set memory 750m
do C:\Research\techange\Stata\do\pathc
do C:\Research\techange\Stata\do\pathcps
log using $path\log\cps6406countsample_serv, replace 

/************************************************************************
	cps6406countsample_serv.do

	REPLICATE KATZ and MURPHY (1992) DATASET METHODOLOGY:
		SERVICES COUNT SAMPLE 1964-2006
	Data was extracted from Unicon.com CD-ROM

	uses:	cps6406merge.do
		ind2.do
************************************************************************/

*	data merging
*do $path\do\cps6406merge.do

clear
cd $path\data\cps
use cps6406
drop hhid hhid2 random segnum sernum _state lineno



/************************************************************************
*		COUNT SAMPLE
*		TOTAL ANNUAL HOURS

*	CRITERIA
	1. 	Worked at least one week

*	AGGREGATING INTO CELLS
	Average weekly salary for 320 cells defined by sex (2), education
	(<12, 12, 13-15, 16<=) and 40 years of experience
	(=min{age-yrs of school-6 , age-18}) and 2-digit industries 
	(17 till 2002, 20 from 2003)

*************************************************************************/


*	IN LABOR FORCE

keep if (ftpt>=1 & ftpt<=4) | (_esr>=1 & _esr<=3) /* _esr is missing in 1994 */
tab year


*	1. 	Worked at least one week

gen wkswk7688 = _wkslyr if year>=76 /* 0=NIU, 1-52 */
tab wkswk7688
replace wkswk7688=0 if wkswk7688==.
gen wkswk6475 = wkslyr  if year<=75
tab wkswk6475 
replace wkswk6475=0 if wkswk6475==1 | wkswk6475==9 | wkswk6475==.
/* NIU 0
 0	 1
 1-13  2
14-26  3
27-39  4
40-47  5
48-49	 6
50-52	 7
AF	 9 */
keep if wkswk6475>=2 | wkswk7688>=1 



*************************************************************************
*	2-digit industry indicator, ind2

do $path\do\ind2.do

drop if ind2==17 & year<=102 /* public */
drop if ind2==20 & year>=103 /* public */
drop if ind2==.

*	keep only services
g byte s=(ind2>=10)
keep if s==1
drop s



*************************************************************************
*	CREATE CELLS
*	Average weekly salary for 320 cells defined by sex (2), education
*	(<12, 12, 13-15, 16<=) and 40 years of experience
*	(=min{age-yrs of school-7 , age-17}).

g byte sexn=sex
drop sex
rename sexn sex
label var sex "1=Male, 2=Female"
tab sex



*************************************************************************
*	years of education is not consistent over years

g educ=.
label var educ "years of education"

*	till 1991 use
*		_grdhi	(Highest grade attended)
*		_educ		(Years of educcation completed)
*		grdcom	(Completed highest grade attended)
replace educ=_grdhi if year>=64 & year<=91 
replace educ=_grdhi-1 if year>=64 & year<=91 & grdcom==2 & educ>0	/* grdcom==2; not completed */

*	1992 to 2006 use 
*		grdatn (Educational attainment)
replace educ = 0  if grdatn<=31 & year>=92 & year<=106	/* less than 1st */
replace educ = 4  if grdatn==32 & year>=92 & year<=106	/* 1, 2,3, 4th grade */
replace educ = 6  if grdatn==33 & year>=92 & year<=106	/* 5, 6th grade */
replace educ = 8  if grdatn==34 & year>=92 & year<=106	/* 7, 8th grade */
replace educ = 9  if grdatn==35 & year>=92 & year<=106	/* 9th grade  */
replace educ = 10 if grdatn==36 & year>=92 & year<=106 /* 10th grade */
replace educ = 11 if grdatn==37 & year>=92 & year<=106	/* 11th grade */
replace educ = 12 if (grdatn==38 | grdatn==39) & year>=92 & year<=106	/* 38: 12th grade, no diploma, 39: high school grad */
replace educ = 13 if grdatn==40 & year>=92 & year<=106	/* some college but no degree */
replace educ = 14 if (grdatn==41 | grdatn ==42) & year>=92 & year<=106	/* associate's degree */
replace educ = 16 if grdatn==43 & year>=92 & year<=106	/* bachelor's degree */
replace educ = 18 if grdatn>=44 & year>=92 & year<=106	/* 44: master, 45: professional 46: doctoral */

tab educ year if year>=90 & year<=93
*	tabulation shows that it's not smooth between 91 and 92
*	correcting this by concentrating educ categories before 92:
replace educ=14 if educ>=13 & educ<=15
replace educ=16 if educ>=16 & educ<=17
* replace educ=4 if educ>=1 & educ<=4
* replace educ=6 if educ>=5 & educ<=6
* replace educ=8 if educ>=7 & educ<=8
tab educ year if year>=90 & year<=93
*	even this is not perfect, but not much more can be done

* this way, we can identify the following 5 categories
*	1: less than high school
*	2: just high school
*	3: some college + associate's degree
*	4: college degree, MA, PhD, 18+
g byte edu=1 if educ<12
replace edu=2 if educ==12
replace edu=3 if educ==14
replace edu=4 if educ>=16
label var edu "1<HS, 2=HS, 3=some col, 4=col+"



*************************************************************************
*	experience

g byte exp1=age-educ-6
g byte exp2=age-18
replace exp1=0 if exp1<0
replace exp2=0 if exp2<0
egen byte exp=rmin(exp1 exp2)
drop exp1 exp2
label var exp "experience =min{age-educ-6 , age-18}"
tab exp
gen exp5=ceil(exp/5)
label var exp5 "5-yr intervals of exp: 1-5, 6-10, etc'"
tab exp5



*************************************************************************
*	ANNUAL HOURS WORKED
*	1976-2006: 	usual weekly hrs last year * weeks worked
*	1964-1975: 
*		1. if hrs worked last week>0, then 
*			hrs worked last week * imputed weeks worked
*		2. if hrs worked last week=0, then 
*			imputed hrs worked last week * imputed weeks worked

*	IMPUTED AND ACTUAL WEEKS WORKED

gen wkswka=wkswk6475 if year<=75
replace wkswka=2 if wkswk7688>=1  & wkswk7688<=13 & year>=76
replace wkswka=3 if wkswk7688>=14 & wkswk7688<=26 & year>=76
replace wkswka=4 if wkswk7688>=27 & wkswk7688<=39 & year>=76
replace wkswka=5 if wkswk7688>=40 & wkswk7688<=47 & year>=76
replace wkswka=6 if wkswk7688>=48 & wkswk7688<=49 & year>=76
replace wkswka=7 if wkswk7688>=50 & wkswk7688<=52 & year>=76
sort sex edu exp wkswka
/* Average weeks worked for each cell in 1976- */ 
replace wkswk7688=. if wkswk7688==0
by sex edu exp wkswka: egen wkswk7688avg=mean(wkswk7688)
gen wkswk=wkswk7688 if year>=76 /* Actual weeks 1975- */
replace wkswk=wkswk7688avg if year<=75 /* Imputed weeks before 1975 */
label var wkswk "Weeks of work (imputed for 1964-1975 surveys)"

*	IMPUTED AND ACTUAL HRS WORKED LAST WEEK

g byte fullpart=1 if ftpt==1 | ftpt==3
replace fullpart=2 if ftpt==2 | ftpt==4
/* Code: ftpt
                             62      63-67   68-75   76-01
NIU, children, armed forces          9       0       0
Full-time, full year         2       1       1       1
Part-time, full year         3       2       2       2
Full-time, part year         2       1       3       3
Part-time, part year         3       2       4       4
Nonworker                            9               5 */

/* Code: hours
                             62      63-67   68-93   94-01
NIU (non-interview)                          00      -1
Children and Armed Forces                    00      00
Hours                        01-99   01-98+  01-99+  01-99+
Not working or Armed Forces  100     99 */

replace hours=. if (hours==99 & year<=67) | hours<=0
egen hrsavg=mean(hours), by(year sex fullpart)

gen hrsweek=hrslyr if year>=76
/* 1964-75, hrs worked last week>0 */
replace hrsweek=hours if hrsweek==. & year<=75
/* 1964-75, hrs worked last week=0 */
replace hrsweek=hrsavg if hrsweek==. & year<=75


*	ANNUAL HRS WORKED

gen hrs=hrsweek*wkswk



*	WEIGHTED ANNUAL FRACTION OF HRS WORKED

replace hrs=hrs*wgt/100



*************************************************************************
*	AGGREGATING INTO CELLS

keep year sex edu exp exp5 hrs ind2
keep if exp>=1 & exp<=40
save temp, replace

/*
collapse (sum) hrs, by(year sex edu exp)
sort year
by   year: egen hrspc=pc(hrs), prop
replace hrs=hrspc
drop hrspc
label var hrs "Fraction of total annual hours worked"
order year sex edu exp
sort year sex edu exp
save countsample6406_serv, replace
*/

clear
use temp
collapse (sum) hrs, by(year sex edu exp5)
sort year
by   year: egen hrspc=pc(hrs), prop
replace hrs=hrspc
drop hrspc
label var hrs "Fraction of total annual hours worked"
order year sex edu exp5
sort year sex edu exp5
save countsample6406exp5_serv, replace
clear

erase temp.dta
*************************************************************************
clear
set memory 1m
*/
log close
