*************************************************************************
set more off 
capture log close
set logtype text
clear
set memory 750m
do C:\Research\techange\Stata\do\pathc
do C:\Research\techange\Stata\do\pathcps
log using $path\log\cps6406wagesample, replace 

/************************************************************************
	cps6406wagesample.do

	REPLICATE KATZ and MURPHY (1992) DATASET METHODOLOGY:
		WAGE SAMPLE 1964-2006
	Data was extracted from Unicon.com CD-ROM
************************************************************************/

*	data merging
*do $path\do\cps6406merge.do


*************************************************************************
*	use personal consumption expenditure deflator, base==2000 (100)
*	Implicit deflator from personal consumption expenditures, NIPAs.
*	Table 2.3.3. Real Personal Consumption Expenditures by Major Type of Product, Quantity Indexes
*	Table 2.3.5. Personal Consumption Expenditures by Major Type of Product 
clear
cd $path\data\cps
insheet using pce_def.csv, names
keep year pcedef2000
label var pcedef2000 "personal consumption expenditure deflator, base==2000"
replace year=year-1900+1
sort year
save pce_def, replace
clear
*************************************************************************


clear
cd $path\data\cps
use cps6406
sort year
merge year using pce_def
tab year _merge
drop if _merge==2
drop _merge



/************************************************************************
*		WAGE SAMPLE
*		AVERAGE WEEKLY WAGE

*	CRITERIA
	1. 	Full time workers.
	2. 	In labor force >= 39 weeks.
	3. 	Worked >= 1 week.
	4.	Of the set defined by 1-3, exclude observations that did not
		work ALL YEAR due to school, retirement or military service.
	5.	No self-employed.
	6.	No unpaid workers.

*	CORRECTION FOR ALLOCATING UNREPORTED INCOME

*	TOP-CODING
	1.75 times annual top-coding amount.

*	DEFLATING
	Implicit deflator from personal consumption expenditures, NIPAs.
	Table 2.3.3. Real Personal Consumption Expenditures by Major Type of Product, Quantity Indexes 
	Table 2.3.5. Personal Consumption Expenditures by Major Type of Product 

*	MINIMUM EARNING
	More than $67/week in 1982 prices.

*	AGGREGATING INTO CELLS
	Average weekly salary for 320 cells defined by sex (2), education
	(<12, 12, 13-15, 16<=) and 40 years of experience
	(=min{age-yrs of school-6 , age-18}) and 2-digit industries 
	(17 till 2002, 20 from 2003)

*************************************************************************/



*	IN LABOR FORCE

keep if (ftpt>=1 & ftpt<=4) | (_esr>=1 & _esr<=3) /* _esr is missing in 1994 */
tab year



*	1. 	Full time workers.

* Full-time, full year (1) Full-time, part year (3)
keep if ftpt==1 | ftpt==3 
tab year



*	2. 	In labor force >= 39 weeks.

gen wkswk7688 = _wkslyr if year>=76 /* 0=NIU, 1-52 */
tab wkswk7688
replace wkswk7688=0 if wkswk7688==.
gen wkswk6475 = wkslyr  if year<=75
tab wkswk6475 
replace wkswk6475=0 if wkswk6475==1 | wkswk6475==9 | wkswk6475==.
/* NIU 0
 0	 1
 1-13  2
14-26  3
27-39  4
40-47  5
48-49	 6
50-52	 7
AF	 9 */

gen wksun6888 = wksun if year>=68 /* 0=NIU, 1-52, 53-99 */
tab wksun6888
replace wksun6888=0 if wksun6888==.
replace wksun6888=0 if wksun6888>52 /* these are nonsense values */
gen wksun6467 = wksun if year<=67
tab wksun6467
replace wksun6467=0 if wksun6467==1 | wksun6467>=17 | wksun6467==.
/* NIU 00
<1	 01
 1	 02
 2	 03
 3	 04
 4	 05
 5	 06
 6	 07
 7-10	 08
11-14	 09
15-18	 10
19-22	 11
23-26	 12
27-34	 13
35-42	 14
43-50	 15
51-52	 16
>52	 17
Not UE 99 */

drop wksun 

* labor force participation is either employed or unemployed

/*	MAXIMAL values of interval
*	1964-1967
gen lf39=1 if wkswk6475>=4
replace lf39=1 if wksun6467>=14
replace lf39=1 if wkswk6475>=3 & wksun6467>=9
replace lf39=1 if wkswk6475>=2 & wksun6467>=12
*	1968-1975
replace lf39=1 if wkswk6475>=4
replace lf39=1 if wksun6888>=39
replace lf39=1 if wkswk6475>=3 & wksun6888>=13
replace lf39=1 if wkswk6475>=2 & wksun6888>=26
*	1975-1988
replace lf39=1 if wkswk7688+wksun6888>=39 
*/
*	MINIMAL values of interval
*	1964-1967
gen lf39=1 if wkswk6475>=5
replace lf39=1 if wksun6467>=14
replace lf39=1 if wkswk6475>=4 & wksun6467>=9
replace lf39=1 if wkswk6475>=3 & wksun6467>=12
*	1968-1975
replace lf39=1 if wkswk6475>=5
replace lf39=1 if wksun6888>=39
replace lf39=1 if wkswk6475>=4 & wksun6888>=12
replace lf39=1 if wkswk6475>=3 & wksun6888>=25
replace lf39=1 if wkswk6475>=2 & wksun6888>=38
*	1975-1988
replace lf39=1 if wkswk7688+wksun6888>=39 

keep if lf39==1
drop lf39



*	3. 	Worked >= 1 week.

keep if wkswk6475>=2 | wkswk7688>=1 



*	4.	Of the set defined by 1-3, exclude observations that did not
*		work ALL YEAR due to school, retirement or military service.

tab _pyrsn
drop if _pyrsn>=3 & _pyrsn<=5
/* Code: pyrsn                                           Recode: _pyrsn
                            62   76-83   84-88   88B-01  62-01
NIU                              0       0       0       0
Looking for work            0*                           8*
Ill/disabled                1    1       1       1       1
Taking care of home/family  3    2       2       2       2
Going to school             4    3       3       3       3
In Armed Forces                  4                       4
Retired                          5       5       4       5
No work available                        6       5       6
Unpaid work                 2                            9
Other                       5    6       7       6       7
Full year or nonworkers     6                            0 */

tab rprtyr
drop if rprtyr>=4 & rprtyr<=6
/* Code: rprtyr
                                   68-88
               NIU                 0
               Looking/unemployed  1
               Ill/disabled        2
               Keeping house       3
               Going to school     4
               Armed Forces        5
               Retired             6
               Other               7
               Full year worker    8
               Never worked        9 */

display _N



*	5.	No self-employed.

tab clslyr if year<=75
tab clslyr if year>=76 /* mistake in labels */
drop if clslyr==3 & year<=75
drop if (clslyr==5 | clslyr==6) & year>=76
/* Code: clslyr                                         Recode:
                                62  63-67  68-75  76-01 62-01
NIU                                          0      0     0
Private                           0*   1     1      1     1
Government                        1    2     2            2
Federal government                                  2     2
State government                                    3     2
Local government                                    4     2
Self-employed                     2    3     3            3
Self-employed, incorporated                         5     1
Self-employed, not incor or farm                    6     3
Without pay                       3    4     4      7     4
Not available                          9                  9 */

tab year



*	6.	No unpaid workers.

drop if clslyr==4 & year<=75
drop if clslyr==7 & year>=76
keep if incwag>0
drop clslyr 
display _N



**************************************************************************
*	TOP-CODING

*	correct for top coding, adjust by local `tc'

local tc=1.75

/* Code: incwag
                      06-96     95-88B  88-85  84-82  81-76  75-68   67-62
        None or NIU   000000    000000  00000  00000  00000  000000  00000
        Top value     varies    199998  99999  75000  50000  +50000  99999
        NIU                                                  099999  
        Blank                                                        .
        Recode:NIU                                           .       

after 1996 they gave class average numbers for top coded earnings */ 

tab year if incwag==.
drop if incwag==.

*	top code indicator
g byte tc=0
*replace tc=1 if year>=64 & year<=67 & incwag==99900 /* mistake in coding */
replace tc=1 if year>=68 & year<=81 & incwag==50000
replace tc=1 if year>=82 & year<=84 & incwag==75000
replace tc=1 if year>=85 & year<=88 & incwag==99999
/* 
top-coding in 1989-95: there is a huge mass point at 99999
from Appendix H:
incwag  Income from wage and salary 
              [88B-06: incwg1 + (incer1 if ernsrc=1)
                       If both vars are topcoded in 88B-95***, then the max 
                       value will be 199998.  If only one is top coded, then
                       the max value will range between 99999 and 199998.]

incwg1  Income from other wage and salary 
                88B-95             0               99999*           00000
                96-01              0               25000*           00000
incer1  Earnings from longest job before deductions
                88B-95         -9999*              99999*          000000
                96-01          -9999*             150000*          000000
*/
replace tc=1 if year>=89 & year<=95 & incwag>=99999
* this keeps the number of top-coded observations consistent with trends
*replace tc=1 if year>=96  & year<=102 & incwg1>25000
replace tc=1 if year>=96  & year<=102 & incer1>150000 & ernsrc==1
*replace tc=1 if year>=103 & year<=106 & incwg1>35000
replace tc=1 if year>=103 & year<=106 & incer1>200000 & ernsrc==1
label var tc "wage top-coding indicator"
tab year tc

*	correction for top coding
replace incwag=incwag*`tc' if tc==1 & year<=88
replace incwag=99999*`tc'+(incwag-99999) if tc==1 & incwag<199998 & year>=89 & year<=95
replace incwag=incwag*`tc' if incwag==199998 & year>=89 & year<=95
* no need to adjust wages from 1996 and on.  see appendix H.
**************************************************************************



*************************************************************************
*	2-digit industry indicator, ind2

do $path\do\ind2.do

drop if ind2==17 & year<=102 /* public */
drop if ind2==20 & year>=103 /* public */
drop if ind2==.

g byte sec = 1 + (ind2>=10)
label var sec "1=goods+low skill serv, 2=high skill serv"



*************************************************************************
*	CREATE CELLS
*	Average weekly salary for 320 cells defined by sex (2), education
*	(<12, 12, 13-15, 16<=) and 40 years of experience
*	(=min{age-yrs of school-6 , age-18}).

g byte sexn=sex
drop sex
rename sexn sex
label var sex "1=Male, 2=Female"
tab sex



*************************************************************************
*	years of education is not consistent over years

g educ=.
label var educ "years of education"

*	till 1991 use
*		_grdhi	(Highest grade attended)
*		_educ		(Years of educcation completed)
*		grdcom	(Completed highest grade attended)
replace educ=_grdhi if year>=64 & year<=91 
replace educ=_grdhi-1 if year>=64 & year<=91 & grdcom==2 & educ>0	/* grdcom==2; not completed */

*	1992 to 2006 use 
*		grdatn (Educational attainment)
replace educ = 0  if grdatn<=31 & year>=92 & year<=106	/* less than 1st */
replace educ = 4  if grdatn==32 & year>=92 & year<=106	/* 1, 2,3, 4th grade */
replace educ = 6  if grdatn==33 & year>=92 & year<=106	/* 5, 6th grade */
replace educ = 8  if grdatn==34 & year>=92 & year<=106	/* 7, 8th grade */
replace educ = 9  if grdatn==35 & year>=92 & year<=106	/* 9th grade  */
replace educ = 10 if grdatn==36 & year>=92 & year<=106 /* 10th grade */
replace educ = 11 if grdatn==37 & year>=92 & year<=106	/* 11th grade */
replace educ = 12 if (grdatn==38 | grdatn==39) & year>=92 & year<=106	/* 38: 12th grade, no diploma, 39: high school grad */
replace educ = 13 if grdatn==40 & year>=92 & year<=106	/* some college but no degree */
replace educ = 14 if (grdatn==41 | grdatn ==42) & year>=92 & year<=106	/* associate's degree */
replace educ = 16 if grdatn==43 & year>=92 & year<=106	/* bachelor's degree */
replace educ = 18 if grdatn>=44 & year>=92 & year<=106	/* 44: master, 45: professional 46: doctoral */

tab educ year if year>=90 & year<=93
*	tabulation shows that it's not smooth between 91 and 92
*	correcting this by concentrating educ categories before 92:
replace educ=14 if educ>=13 & educ<=15
replace educ=16 if educ>=16 & educ<=17
* replace educ=4 if educ>=1 & educ<=4
* replace educ=6 if educ>=5 & educ<=6
* replace educ=8 if educ>=7 & educ<=8
tab educ year if year>=90 & year<=93
*	even this is not perfect, but not much more can be done

* this way, we can identify the following 5 categories
*	1: less than high school
*	2: just high school
*	3: some college + associate's degree
*	4: college degree, MA, PhD, 18+
g byte edu=1 if educ<12
replace edu=2 if educ==12
replace edu=3 if educ==14
replace edu=4 if educ>=16
label var edu "1<HS, 2=HS, 3=some col, 4=col+"



*************************************************************************
*	experience

g byte exp1=age-educ-6
g byte exp2=age-18
replace exp1=0 if exp1<0
replace exp2=0 if exp2<0
egen byte exp=rmin(exp1 exp2)
drop exp1 exp2
label var exp "experience =min{age-educ-6 , age-18}"
tab exp
gen exp5=ceil(exp/5)
label var exp5 "5-yr intervals of exp: 1-5, 6-10, etc'"
tab exp5



**************************************************************************
*	CORRECTION FOR ALLOCATING UNREPORTED INCOME

/* Code: aincwag
                                         62-75      76-88
Not allocated                            0, .       0
Allocated                                1
Income amount allocated                             1
Recipiency type allocated                           2
Income and recipiency type allocated                3 
*** actually, alocation is only from 1968 survey */

tab year if aincwag==. & year>=68 & year<=75 /* not allocated */
tab year if aincwag==0 & year>=68 & year<=75 /* not allocated */
tab year if aincwag==1 & year>=68 & year<=75 /* allocated */
sum year aincwag if year>=68 & year<=75
tab year aincwag if year>=76
sum year aincwag if year>=76
gen y=1 if year>=68 & year<=75
replace y=2 if year>=76
gen alc = (aincwag==1 | aincwag==2 | aincwag==3)
tab alc if y==1
tab alc if y==2
gen w1a=incwag if y==1 & alc==1
gen w1n=incwag if y==1 & alc==0
gen w2a=incwag if y==2 & alc==1
gen w2n=incwag if y==2 & alc==0
sort sex edu exp
by   sex edu exp: egen w1am=mean(w1a)
by   sex edu exp: egen w1nm=mean(w1n)
by   sex edu exp: egen w2am=mean(w2a)
by   sex edu exp: egen w2nm=mean(w2n)
* adjustment factor for alocated income in 1968-1975 surveys:
gen k=(w2am/w2nm)/(w1am/w1nm) if y==1 & alc==1
sum k, d
replace incwag=incwag*k if y==1 & alc==1
drop w1a w1n w2a w2n w1am w1nm w2am w2nm k



**************************************************************************
*	AVERAGE WEEKLY WAGE

gen wkswka=wkswk6475 if year<=75
replace wkswka=2 if wkswk7688>=1 & wkswk7688<=13 & year>=76
replace wkswka=3 if wkswk7688>=14 & wkswk7688<=26 & year>=76
replace wkswka=4 if wkswk7688>=27 & wkswk7688<=39 & year>=76
replace wkswka=5 if wkswk7688>=40 & wkswk7688<=47 & year>=76
replace wkswka=6 if wkswk7688>=48 & wkswk7688<=49 & year>=76
replace wkswka=7 if wkswk7688>=50 & wkswk7688<=52 & year>=76
/* Average weeks worked for each cell in 1976- */ 
replace wkswk7688=. if wkswk7688==0
egen wkswk7688avg=mean(wkswk7688), by(sex wkswka)
replace wkswk7688avg=round(wkswk7688avg,1)
gen wkswk=wkswk7688 if year>=76 /* Actual weeks 1975- */
replace wkswk=wkswk7688avg if year<=75 /* Imputed weeks before 1975 */
label var wkswk "Weeks of work (imputed for 1963-1974)"

gen wkswage=incwag/wkswk


*	DEFLATING

gen wksrwage=(wkswage/pcedef2000)*100


*	MINIMUM EARNING

* dropping if real wage is less than $67 per week in 1982 prices.
* hence i adjust $67 to 2000 prices.
drop if wksrwage<67/59.85904625*100



*************************************************************************
*	AGGREGATING INTO CELLS

keep year sex edu exp exp5 ind2 wksrwage sec
keep if exp>=1 & exp<=40
save temp, replace

/*
collapse (mean) wksrwage, by(year sex edu exp)
label var wksrwage "real weekly wage in 2000 prices"
compress
sort year sex edu exp
save wagesample6406, replace
clear
*/

use temp
collapse (mean) wksrwage, by(year sex edu exp5)
label var wksrwage "real weekly wage in 2000 prices"
compress
sort year sex edu exp5
save wagesample6406exp5, replace

clear
use temp
collapse (mean) wksrwage, by(year ind2 sex edu exp5)
label var wksrwage "real weekly wage in 2000 prices"
order year ind2 sex edu exp5
compress
sort year ind2 sex edu exp5
save wagesample6406ind2, replace

clear
use temp
collapse (mean) wksrwage, by(year sec sex edu exp5)
label var wksrwage "real weekly wage in 2000 prices"
order year sec sex edu exp5
compress
sort year sec sex edu exp5
save wagesample6406sec, replace

erase temp.dta
*************************************************************************
clear
set memory 1m
*/
log close
