*************************************************************************
set more off 
capture log close
set logtype text
clear
set memory 150m
do C:\_PAPERS\techange\Stata\do\pathc

/************************************************************************
	data_for_estimation2.do

	use aggregate equivalence weights to create college and HS
	equivalents -- for all industries

ind2 
1	Agriculture, forestry, & fisheries
2	Mining
3	Construction
4	Manufacturing, nondurable goods
5	Manufacturing, durable goods
6	Transportation (inc. USPS)
7	Communications & other public utilities
8	Wholesale trade
9	Retail trade
10	Finance, insurance & real estate
11	Business & repair services
12	Personal services
13	Entertainment & recreation services
14	Health services
15	Educational services
16	Other professional & related services

SECTORS A LA LEE-WOLPIN (2006) ECA
The goods-producing sector consists of the agriculture, mining, construction, and manufacturing 
... the service sector consists of the transportation and public utilities, trade, finance, 
insurance, real estate, private household service, miscellaneous service, 
and public administration industry categories.

GOODS + LOW SKILL SERVICES: ONLY GOODS, ind2<=5
SERVICES: ALL SERVICES,	ind2>=6

!!! PROBLEM: skill intensity in goods <0 due to large <0 weight on HS dropouts !!!
************************************************************************/

cd $path\data\cps

/* data generating do-files:
do $path\do\cps6406countsample.do
do $path\do\cps6406wagesample.do
do $path\do\cps6406countsample_manu.do
do $path\do\cps6406wagesample_manu.do
do $path\do\cps6406countsample_serv.do
do $path\do\cps6406wagesample_serv.do
do $path\do\cps6406countsample_goodserv.do
do $path\do\cps6406wagesample_goodserv.do
*/
*do $path\do\ind2convert1990-2000countsample.do


****************************************************************************
*	INDUSTRY DATA

clear
use countsample6406ind2corrected
sort year ind2 sex edu exp5
save countsample6406ind2corrected, replace
clear
****************************************************************************



****************************************************************************
*	AGGREGATE
*	not using industry classifications at all

clear
use wagesample6406exp5
merge year sex edu exp5 using countsample6406exp5, sort
tab _merge
list year sex edu exp if _merge==2
drop _merge

*	GENERATE FIXED N VECTOR OF HOURS WEIGHTS
egen N=mean(hrs), by(sex edu exp5)
label var N "Average hours share, by cell (time-fixed weights vector for wage aggregation)"

*	GENERATE ANNUAL WGAE INDEX N'W
gen NW=N*wksrwage
egen NWindex=sum(NW), by(year)
label var NWindex "Annual average real wage index"
label var NW "Real wage weighted by average hours (=N*wksrwage)"

*	GENERATE RELATIVE WAGES
gen relwksrwage=wksrwage/NWindex
label var relwksrwage "Relative weekly real wages"

*	GENERATE FIXED W VECTOR OF WAGES WEIGHTS
egen W=mean(relwksrwage), by(sex edu exp5)
label var W "Average wages by cell (time-fixed weights vector for hours aggregation)"

*	GENERATE LABOR SUPPLY IN RELATIVE EFFICIENCY UNITS
gen hrseff=hrs*W
egen hrseffpc=pc(hrseff), prop by(year)
drop hrseff
rename hrseffpc hrseff
label var hrseff "Fraction of total annual hours worked in relative efficiency units"
sort year sex edu exp5
save NWsample5, replace


*	REGRESSIONS for COL and HS EQUIVALENTS
*	COLLEGE/HS PREMIUMS

egen Nedu=sum(N), by(year edu)
gen w=NW/Nedu
collapse (sum) w, by(year edu)
reshape wide w, i(year) j(edu)

qui reg w1 w2 w4, noconst 
mat b=e(b)
local e1hs=b[1,1]
local e1col=b[1,2]
qui reg w3 w2 w4, noconst 
mat b=e(b)
local e3hs=b[1,1]
local e3col=b[1,2]

display `e1hs'
display `e1col'
display `e3hs'
display `e3col'

gen pxAG=w4/w2
keep year pxAG
save pxAG, replace
clear

use NWsample5
collapse hrs, by(year edu)
reshape wide hrs, i(year) j(edu)
gen hsAG = hrs2 + (`e1hs'*hrs1) + (`e3hs'*hrs3)
gen colAG = hrs4 + (`e1col'*hrs1) + (`e3col'*hrs3)
gen xAG = colAG/hsAG
drop hrs*
merge year using pxAG, sort
tab _merge
drop _merge
save pxAG, replace
clear
****************************************************************************



****************************************************************************
*	GOODS + LOW SKILL SERVICES: ONLY GOODS

clear
use countsample6406ind2corrected
keep if ind2<=5
collapse (sum) hrs, by(year sex edu exp5)
egen h=total(hrs), by(year)
**replace hrs=hrs/h
drop h

merge year sex edu exp5 using wagesample6406exp5_goodserv, sort
tab _merge
list year sex edu exp if _merge==2
drop _merge

*	GENERATE FIXED N VECTOR OF HOURS WEIGHTS
egen N=mean(hrs), by(sex edu exp5)
label var N "Average hours share, by cell (time-fixed weights vector for wage aggregation)"

*	GENERATE ANNUAL WGAE INDEX N'W
gen NW=N*wksrwage
egen NWindex=sum(NW), by(year)
label var NWindex "Annual average real wage index"
label var NW "Real wage weighted by average hours (=N*wksrwage)"

*	GENERATE RELATIVE WAGES
gen relwksrwage=wksrwage/NWindex
label var relwksrwage "Relative weekly real wages"

*	GENERATE FIXED W VECTOR OF WAGES WEIGHTS
egen W=mean(relwksrwage), by(sex edu exp5)
label var W "Average wages by cell (time-fixed weights vector for hours aggregation)"

*	GENERATE LABOR SUPPLY IN RELATIVE EFFICIENCY UNITS
gen hrseff=hrs*W
egen hrseffpc=pc(hrseff), prop by(year)
drop hrseff
rename hrseffpc hrseff
label var hrseff "Fraction of total annual hours worked in relative efficiency units"

sort year sex edu exp5
save NWsample5goodserv, replace

*	college and HS equivalents

egen Nedu=sum(N), by(year edu)
gen w=NW/Nedu
collapse (sum) w, by(year edu)
reshape wide w, i(year) j(edu)

gen pxGS=w4/w2
keep year pxGS
save pxGS, replace
clear

use NWsample5goodserv
collapse hrs, by(year edu)
reshape wide hrs, i(year) j(edu)
gen hsGS = hrs2 + (`e1hs'*hrs1) + (`e3hs'*hrs3)
gen colGS = hrs4 + (`e1col'*hrs1) + (`e3col'*hrs3)
gen xGS = colGS/hsGS

drop hrs*
merge year using pxGS, sort
tab _merge
drop _merge
save pxGS, replace
clear
****************************************************************************



****************************************************************************
*	SERVICES

clear
use countsample6406ind2corrected
keep if ind2>=6
collapse (sum) hrs, by(year sex edu exp5)
egen h=total(hrs), by(year)
*replace hrs=hrs/h
drop h

merge year sex edu exp5 using wagesample6406exp5_serv, sort
tab _merge
list year sex edu exp if _merge==2
drop _merge

*	GENERATE FIXED N VECTOR OF HOURS WEIGHTS
egen N=mean(hrs), by(sex edu exp5)
label var N "Average hours share, by cell (time-fixed weights vector for wage aggregation)"

*	GENERATE ANNUAL WGAE INDEX N'W
gen NW=N*wksrwage
egen NWindex=sum(NW), by(year)
label var NWindex "Annual average real wage index"
label var NW "Real wage weighted by average hours (=N*wksrwage)"

*	GENERATE RELATIVE WAGES
gen relwksrwage=wksrwage/NWindex
label var relwksrwage "Relative weekly real wages"

*	GENERATE FIXED W VECTOR OF WAGES WEIGHTS
egen W=mean(relwksrwage), by(sex edu exp5)
label var W "Average wages by cell (time-fixed weights vector for hours aggregation)"

*	GENERATE LABOR SUPPLY IN RELATIVE EFFICIENCY UNITS
gen hrseff=hrs*W
egen hrseffpc=pc(hrseff), prop by(year)
drop hrseff
rename hrseffpc hrseff
label var hrseff "Fraction of total annual hours worked in relative efficiency units"

sort year sex edu exp5
save NWsample5serv, replace

*	college and HS equivalents

egen Nedu=sum(N), by(year edu)
gen w=NW/Nedu
collapse (sum) w, by(year edu)
reshape wide w, i(year) j(edu)

gen pxSV=w4/w2
keep year pxSV
save pxSV, replace
clear

use NWsample5serv
collapse hrs, by(year edu)
reshape wide hrs, i(year) j(edu)
gen hsSV = hrs2 + (`e1hs'*hrs1) + (`e3hs'*hrs3)
gen colSV = hrs4 + (`e1col'*hrs1) + (`e3col'*hrs3)
gen xSV = colSV/hsSV

drop hrs*
merge year using pxSV, sort
tab _merge
drop _merge
save pxSV, replace
clear
****************************************************************************



****************************************************************************
*	MANUFACTURING

clear
use countsample6406ind2corrected
keep if ind2>=4 & ind2<=5
collapse (sum) hrs, by(year sex edu exp5)
egen h=total(hrs), by(year)
*replace hrs=hrs/h
drop h

merge year sex edu exp5 using wagesample6406exp5_manu, sort
tab _merge
list year sex edu exp if _merge==2
drop _merge

*	GENERATE FIXED N VECTOR OF HOURS WEIGHTS
egen N=mean(hrs), by(sex edu exp5)
label var N "Average hours share, by cell (time-fixed weights vector for wage aggregation)"

*	GENERATE ANNUAL WGAE INDEX N'W
gen NW=N*wksrwage
egen NWindex=sum(NW), by(year)
label var NWindex "Annual average real wage index"
label var NW "Real wage weighted by average hours (=N*wksrwage)"

*	GENERATE RELATIVE WAGES
gen relwksrwage=wksrwage/NWindex
label var relwksrwage "Relative weekly real wages"

*	GENERATE FIXED W VECTOR OF WAGES WEIGHTS
egen W=mean(relwksrwage), by(sex edu exp5)
label var W "Average wages by cell (time-fixed weights vector for hours aggregation)"

*	GENERATE LABOR SUPPLY IN RELATIVE EFFICIENCY UNITS
gen hrseff=hrs*W
egen hrseffpc=pc(hrseff), prop by(year)
drop hrseff
rename hrseffpc hrseff
label var hrseff "Fraction of total annual hours worked in relative efficiency units"

sort year sex edu exp5
save NWsample5manu, replace

*	college and HS equivalents

egen Nedu=sum(N), by(year edu)
gen w=NW/Nedu
collapse (sum) w, by(year edu)
reshape wide w, i(year) j(edu)

gen pxMN=w4/w2
keep year pxMN
save pxMN, replace
clear

use NWsample5manu
collapse hrs, by(year edu)
reshape wide hrs, i(year) j(edu)
gen hsMN = hrs2 + (`e1hs'*hrs1) + (`e3hs'*hrs3)
gen colMN = hrs4 + (`e1col'*hrs1) + (`e3col'*hrs3)
gen xMN = colMN/hsMN

drop hrs*
merge year using pxMN, sort
tab _merge
drop _merge
save pxMN, replace
clear
****************************************************************************



*************************************************************************
*	MERGE

clear
use pxAG
merge year using pxMN pxSV pxGS, sort
erase pxAG.dta
erase pxMN.dta
erase pxSV.dta
erase pxGS.dta
sum _merge*
drop _merge*


*	EMPLOYMENT SHARES

*	share of college equivalents
g colGSshare=colGS/colAG*100
g colSVshare=colSV/colAG*100
g colMNshare=colMN/colAG*100

*	share of HS equivalents
g hsGSshare=hsGS/hsAG*100
g hsSVshare=hsSV/hsAG*100
g hsMNshare=hsMN/hsAG*100

*	share of total employment
g empSV = (colSVshare*xAG/(1+xAG)) + (hsSVshare/(1+xAG))
g empGS = ((100-colSVshare)*xAG/(1+xAG)) + ((100-hsSVshare)/(1+xAG))
g empMN = (colMNshare*xAG/(1+xAG)) + (hsMNshare/(1+xAG))
*g empGS1 = (colGSshare*xAG/(1+xAG)) + (hsGSshare/(1+xAG))
*g empGS2 = 100-empSV

replace year=year+1900-1
aorder
order year
sort year
g byte t=_n
compress
save data_for_estimation3, replace
*************************************************************************


/*
*************************************************************************
*	FIGURES

label var colGSshare "Goods"
label var colSVshare "Services"
label var hsGSshare "Goods"
label var hsSVshare "Services"

label var pxAG "Relative Wage"
label var xAG "Relative Supply"
twoway (scatter pxAG year, yaxis(1) connect(l) msymbol(Oh) ///
	title("Relative Wage and Relative Supply of College Graduates")  ///
	xtitle("") xlabel(1965(5)2005) legend(pos(11) ring(0) rows(7) size(small)) ///
	note("Note: Ratio of college wages to HS wages and ratio of college to HS equivalents.") ) ///
	(scatter xAG year, yaxis(2) connect(l) msymbol(O))
graph export $path\graphs\pxAG_xAG.wmf, as(wmf) replace

label var xAG "Aggregate"
label var xGS "Goods"
label var xSV "Services"

scatter xGS xSV xAG year, connect(l l l) msymbol(S T O) ///
	scheme(s1color) ///
	xlabel(1965(5)2005) xtitle("") ///
	mc(cranberry navy green) lc(cranberry navy green) ///
	legend(cols(3)) ///
	note("Note: Ratio of college to high-school equivalents.")
graph export $path\graphs\x.wmf, as(wmf) replace

scatter xGS xSV xAG year, connect(l l l) msymbol(S T O) ///
	ti(B. Skill Intensities) ///
	scheme(s1color) ///
	xlabel(1970(10)2000) xtitle("") ///
	ytitle(College/High-School Equivalents) ///
	mc(cranberry navy green) lc(cranberry navy green) ///
	legend(cols(2) order(1 2)) 
graph save $path\graphs\x.gph, replace


label var pxAG "Aggregate"
label var pxGS "Goods"
label var pxSV "Services"
scatter pxSV pxAG pxGS year, connect(l l l) msymbol(T O S) ///
	title("Relative Wage and Relative Supply of College Graduates")  ///
	xtitle("") xlabel(1965(5)2005) ///
	legend(pos(11) ring(0) rows(7) size(small)) ///
	note("Note: Ratio of college to HS equivalents.")
graph export $path\graphs\px.wmf, as(wmf) replace

label var empGS "Goods"
label var empSV "Services"
scatter empGS empSV year, connect(l l) msymbol(S T) /*
*/	title("Employment Shares") /*
*/	xlabel(1965(5)2005) xtitle("") /*
*/	ytitle("Percent") /*
*/	legend(pos(1) ring(0) rows(2) size(small)) /*
*/	note("Note: College and high-school equivalents.")
graph export $path\graphs\employment_shares.wmf, as(wmf) replace



*scatter colSVshare colGSshare year, connect(l l) msymbol(Oh Th) /*
*/	title("Share of college-equivalents") /*
*/	xlabel(1965(5)2005,labsize(small)) xtitle("") /*
*/	ylabel(,labsize(small)) ytitle("Percent",size(small)) /*
*/	legend(pos(1) ring(0) rows(2) size(small)) /*
*/	note("Source: CPS, using aggregate weights for college and HS equivalents.")
*graph export $path\graphs\employment_shares_college.wmf, as(wmf) replace

*scatter hsSVshare hsGSshare year, connect(l l) msymbol(Oh Th) /*
*/	title("Share of HS-equivalents") /*
*/	xlabel(1965(5)2005,labsize(small)) xtitle("") /*
*/	ylabel(,labsize(small)) ytitle("Percent",size(small)) /*
*/	legend(pos(1) ring(0) rows(2) size(small)) /*
*/	note("Source: CPS, using aggregate weights for college and HS equivalents.")
*graph export $path\graphs\employment_shares_hs.wmf, as(wmf) replace

label var colGSshare "col"
label var colSVshare "col"
label var hsGSshare "hs"
label var hsSVshare "hs"

*scatter colSVshare hsSVshare year, connect(l l) msymbol(Oh Th) /*
*/	title("Employment shares in services") /*
*/	xlabel(1965(5)2005,labsize(small)) xtitle("") /*
*/	ylabel(,labsize(small)) ytitle("Percent",size(small)) /*
*/	legend(pos(1) ring(0) rows(2) size(small)) /*
*/	note("Source: CPS, using aggregate weights for college and HS equivalents.")
*graph export $path\graphs\employment_shares_serv.wmf, as(wmf) replace

*scatter colGSshare hsGSshare year, connect(l l) msymbol(Oh Th) /*
*/	title("Employment shares in goods+util+trade") /*
*/	xlabel(1965(5)2005,labsize(small)) xtitle("") /*
*/	ylabel(,labsize(small)) ytitle("Percent",size(small)) /*
*/	legend(pos(1) ring(0) rows(2) size(small)) /*
*/	note("Source: CPS, using aggregate weights for college and HS equivalents.")
*graph export $path\graphs\employment_shares_goodserv.wmf, as(wmf) replace

*************************************************************************
*/

*
*************************************************************************
*	EXPORT DATA TO MATLAB FOLDER IN TXT

* !!! PROBLEM: skill intensity in goods <0 due to large <0 weight on HS dropouts !!!
* cprrecting this:
replace xGS=0.004 if year==1963

keep year pxAG xAG xSV xGS colSVshare hsSVshare empSV empGS
order year pxAG xAG xSV xGS colSVshare hsSVshare empSV empGS
outsheet using C:\_PAPERS\techange\Matlab\data_for_estimation3.txt, nonames replace
*************************************************************************
*/

*clear
*set memory 1m

erase NWsample5.dta
erase NWsample5manu.dta
erase NWsample5serv.dta
erase NWsample5goodserv.dta
