*************************************************************************
set more off 
capture log close
set logtype text
clear
set memory 50m
do C:\_PAPERS\techange\Stata\do\pathc

/************************************************************************
	data_for_estimation_relprice.do

	calculate price index for high skilled services relative to 
	goods+low skill services.

id	industry
2	Private industries
3	Agriculture, forestry, fishing, and hunting
6	Mining
10	Utilities
11	Construction
12	Manufacturing
34	Wholesale trade
35	Retail trade
36	Transportation and warehousing
45	Information
50	Finance, insurance, real estate, rental, and leasing
59	Professional and business services
68	Educational services, health care, and social assistance
74	Arts, entertainment, recreation, accommodation, and food services
81	Other services, except government

SECTORS A LA LEE-WOLPIN (2006) ECA
The goods-producing sector consists of the agriculture, mining, construction, and manufacturing 
... the service sector consists of the transportation and public utilities, trade, finance, 
insurance, real estate, private household service, miscellaneous service, 
and public administration industry categories.

g byte gs=(id>=3 & id<=12 & id~=10)+2*(id>=34 & id<=81 | id==10)
************************************************************************/

cd C:\_PAPERS\techange\data

clear
insheet using "va by industry.csv", names
reshape long va, i(id) j(year)
order id ind year va
label var va "Value Added, BN dollars"
sort id year
save temp, replace

clear
insheet using "price indices by industry.csv", names
reshape long p, i(id) j(year)
order id ind year p
label var p "Chain-Type Price Index, 2000=100"
sort id year

merge id year using temp
erase temp.dta
tab _merge
drop _merge
sort id year
save va_p, replace

*	KEEP ONLY RELEVANT YEARS AND INDUSTRIES

keep if year>=1963 & year<=2005
*	these industries comprise the private sector (id==2)
keep if id==3 | id==6 | id==10 | id==11 | id==12 | id==34 | id==35 | id==36 | ///
	id==45 | id==50 | id==59 | id==68 | id==74 | id==81 
tab ind

egen pva=pc(va), by(year) prop

g byte gs=(id>=3 & id<=12 & id~=10)+2*(id>=34 & id<=81 | id==10)

replace p=p*pva
collapse (sum) p pva, by(gs year)
replace p=p/pva
rename pva va
reshape wide p va, i(year) j(gs)

g p21=p2/p1
g p21_1=p21[1]
replace p21=p21/p21_1
drop p21_1

g va21=va2/va1
g va21_1=va21[1]
replace va21=va21/va21_1
drop va21_1

g o21=va21/p21

g lva21=log(va21)
g lp21=log(p21)
g lo21=log(o21)


*	REGRESSIONS

reg lo21 lp21
reg lp21 lo21

reg lo21 lp21 year
reg lp21 lo21 year

/*

*	FIGURES

scatter p21 year, c(l) ///
	xt("") xlab(1965(10)2005) yt("1963=1") scheme(s1color)
graph export C:\_PAPERS\techange\Paper\Figure3_p_relprice3.wmf, as(wmf) replace

scatter o21 year, c(l) ///
	xt("") xlab(1965(10)2005) yt("1963=1") scheme(s1color)
graph export C:\_PAPERS\techange\Paper\Figure3_va_relout3.wmf, as(wmf) replace


scatter p21 year, c(l) ///
	ti(Relative Price Services to Goods) ///
	xt("") xlab(1965(5)2005) ///
	yt("1963=1") ///
	note(Note: Industry prices weighted by value added. Source: BEA.)
graph export C:\_PAPERS\techange\Stata\graphs\p_relprice3.wmf, as(wmf) replace


*replace va1=va1*100
*replace va2=va2*100
label var va1 "Goods"
label var va2 "Services"
scatter va1 va2 year, c(l l) m(S T) ///
	ti(Shares in Value Added) ///
	xt("") xlab(1965(10)2005) scheme(s1color) ///
	yt("Share in Value Added") ///
	legend(cols(1) pos(10) ring(0) size(small)) ///
	caption(Source: BEA.)
graph export C:\_PAPERS\techange\Stata\graphs\va3.wmf, as(wmf) replace

*/

*
*************************************************************************
*	EXPORT DATA TO MATLAB FOLDER IN TXT

keep year p21
order year p21
outsheet using C:\_PAPERS\techange\Matlab\data_for_estimation_relprice3.txt, nonames replace
*************************************************************************
