*************************************************************************
set more off 
capture log close
set logtype text
clear
set memory 50m

/************************************************************************
	data_for_estimation_relprice.do

	calculate price index for high skilled services relative to 
	goods+low skill services.

id	industry
2	Private industries
3	Agriculture, forestry, fishing, and hunting
6	Mining
10	Utilities
11	Construction
12	Manufacturing
34	Wholesale trade
35	Retail trade
36	Transportation and warehousing
45	Information
50	Finance, insurance, real estate, rental, and leasing
59	Professional and business services
68	Educational services, health care, and social assistance
74	Arts, entertainment, recreation, accommodation, and food services
81	Other services, except government

g byte gs=(id>=3 & id<=45)+2*(id>=50 & id<=81)
************************************************************************/

clear
insheet using "va by industry.csv", names
reshape long va, i(id) j(year)
order id ind year va
label var va "Value Added, BN dollars"
sort id year
save temp, replace

clear
insheet using "price indices by industry.csv", names
reshape long p, i(id) j(year)
order id ind year p
label var p "Chain-Type Price Index, 2000=100"
sort id year

merge id year using temp
erase temp.dta
tab _merge
drop _merge
sort id year
save va_p, replace

*	KEEP ONLY RELEVANT YEARS AND INDUSTRIES

keep if year>=1963 & year<=2005
*	these industries comprise the private sector (id==2)
keep if id==3 | id==6 | id==10 | id==11 | id==12 | id==34 | id==35 | id==36 | ///
	id==45 | id==50 | id==59 | id==68 | id==74 | id==81 
tab ind

egen pva=pc(va), by(year) prop

g byte gs=(id>=3 & id<=45)+2*(id>=50 & id<=81)

replace p=p*pva
collapse (sum) p pva, by(gs year)
replace p=p/pva
rename pva va
reshape wide p va, i(year) j(gs)

g p21=p2/p1
g p21_1=p21[1]
replace p21=p21/p21_1
drop p21_1

g va21=va2/va1
g va21_1=va21[1]
replace va21=va21/va21_1
drop va21_1

g o21=va21/p21


*************************************************************************
*	EXPORT DATA FOR MATLAB USE

keep year p21
order year p21
outsheet using data_for_estimation_relprice.txt, nonames replace
*************************************************************************
