*************************************************************************
#delimit cr
set more off 
capture log close
set logtype text
clear
set memory 500m


/************************************************************************
	occupation_task_index2.do

	create consistent occupations based on 1990 Census code
	2003-2006 uses Census 2000 code
	1992-2002 uses Census 1990 code
	1983-1991 uses Census 1980 code
	1971-1982 uses Census 1970 code
	1968-1970 uses Census 1960 code

	restrict to countsample

	Data was extracted from Unicon.com CD-ROM

	uses:	cps6406merge.do
		remapjob_ariell.do
		dot77-occ1990n-gen.do
************************************************************************/


/***


*	data merging
*do cps6406merge.do

clear
use cps6406
drop hhid hhid2 random segnum sernum _state lineno


/************************************************************************
*		COUNT SAMPLE
*		TOTAL ANNUAL HOURS

*	CRITERIA
	1. 	Worked at least one week

*	AGGREGATING INTO CELLS
	Average weekly salary for 320 cells defined by sex (2), education
	(<12, 12, 13-15, 16<=) and 40 years of experience
	(=min{age-yrs of school-6 , age-18}) and 2-digit industries 
	(17 till 2002, 20 from 2003)

*************************************************************************/


*	IN LABOR FORCE

/* ftpt - last year; _esr - last week */
keep if (ftpt>=1 & ftpt<=4) | (_esr>=1 & _esr<=3) /* _esr is missing in 1994 */
sum year
sum year if ftpt>=1 & ftpt<=4
sum year if _esr>=1 & _esr<=3


*	1. 	Worked at least one week

gen wkswk7688 = _wkslyr if year>=76 /* 0=NIU, 1-52 */
tab wkswk7688
replace wkswk7688=0 if wkswk7688==.
gen wkswk6475 = wkslyr  if year<=75
tab wkswk6475 
replace wkswk6475=0 if wkswk6475==1 | wkswk6475==9 | wkswk6475==.
/* NIU 0
 0	 1
 1-13  2
14-26  3
27-39  4
40-47  5
48-49	 6
50-52	 7
AF	 9 */
keep if wkswk6475>=2 | wkswk7688>=1 
sum year



*************************************************************************
*	2-digit industry indicator, ind2

do ind2.do

drop if ind2==17 & year<=102 /* public */
drop if ind2==20 & year>=103 /* public */
drop if ind2==.



*************************************************************************
*	CREATE CELLS
*	Average weekly salary for 320 cells defined by sex (2), education
*	(<12, 12, 13-15, 16<=) and 40 years of experience
*	(=min{age-yrs of school-7 , age-17}).

g byte sexn=sex
drop sex
rename sexn sex
label var sex "1=Male, 2=Female"
tab sex



*************************************************************************
*	years of education is not consistent over years

g educ=.
label var educ "years of education"

*	till 1991 use
*		_grdhi	(Highest grade attended)
*		_educ		(Years of educcation completed)
*		grdcom	(Completed highest grade attended)
replace educ=_grdhi if year>=64 & year<=91 
replace educ=_grdhi-1 if year>=64 & year<=91 & grdcom==2 & educ>0	/* grdcom==2; not completed */

*	1992 to 2006 use 
*		grdatn (Educational attainment)
replace educ = 0  if grdatn<=31 & year>=92 & year<=106	/* less than 1st */
replace educ = 4  if grdatn==32 & year>=92 & year<=106	/* 1, 2,3, 4th grade */
replace educ = 6  if grdatn==33 & year>=92 & year<=106	/* 5, 6th grade */
replace educ = 8  if grdatn==34 & year>=92 & year<=106	/* 7, 8th grade */
replace educ = 9  if grdatn==35 & year>=92 & year<=106	/* 9th grade  */
replace educ = 10 if grdatn==36 & year>=92 & year<=106 /* 10th grade */
replace educ = 11 if grdatn==37 & year>=92 & year<=106	/* 11th grade */
replace educ = 12 if (grdatn==38 | grdatn==39) & year>=92 & year<=106	/* 38: 12th grade, no diploma, 39: high school grad */
replace educ = 13 if grdatn==40 & year>=92 & year<=106	/* some college but no degree */
replace educ = 14 if (grdatn==41 | grdatn ==42) & year>=92 & year<=106	/* associate's degree */
replace educ = 16 if grdatn==43 & year>=92 & year<=106	/* bachelor's degree */
replace educ = 18 if grdatn>=44 & year>=92 & year<=106	/* 44: master, 45: professional 46: doctoral */

tab educ year if year>=90 & year<=93
*	tabulation shows that it's not smooth between 91 and 92
*	correcting this by concentrating educ categories before 92:
replace educ=14 if educ>=13 & educ<=15
replace educ=16 if educ>=16 & educ<=17
* replace educ=4 if educ>=1 & educ<=4
* replace educ=6 if educ>=5 & educ<=6
* replace educ=8 if educ>=7 & educ<=8
tab educ year if year>=90 & year<=93
*	even this is not perfect, but not much more can be done

* this way, we can identify the following 5 categories
*	1: less than high school
*	2: just high school
*	3: some college + associate's degree
*	4: college degree, MA, PhD, 18+
g byte edu=1 if educ<12
replace edu=2 if educ==12
replace edu=3 if educ==14
replace edu=4 if educ>=16
label var edu "1<HS, 2=HS, 3=some col, 4=col+"

drop _educ grdatn _grdhi grdcom


*************************************************************************
*	experience

g byte exp1=age-educ-6
g byte exp2=age-18
replace exp1=0 if exp1<0
replace exp2=0 if exp2<0
egen byte exp=rmin(exp1 exp2)
drop exp1 exp2
label var exp "experience =min{age-educ-6 , age-18}"
tab exp
gen exp5=ceil(exp/5)
label var exp5 "5-yr intervals of exp: 1-5, 6-10, etc'"
tab exp5

drop educ


*************************************************************************
*	ANNUAL HOURS WORKED
*	1976-2006: 	usual weekly hrs last year * weeks worked
*	1964-1975: 
*		1. if hrs worked last week>0, then 
*			hrs worked last week * imputed weeks worked
*		2. if hrs worked last week=0, then 
*			imputed hrs worked last week * imputed weeks worked

*	IMPUTED AND ACTUAL WEEKS WORKED

gen wkswka=wkswk6475 if year<=75
replace wkswka=2 if wkswk7688>=1  & wkswk7688<=13 & year>=76
replace wkswka=3 if wkswk7688>=14 & wkswk7688<=26 & year>=76
replace wkswka=4 if wkswk7688>=27 & wkswk7688<=39 & year>=76
replace wkswka=5 if wkswk7688>=40 & wkswk7688<=47 & year>=76
replace wkswka=6 if wkswk7688>=48 & wkswk7688<=49 & year>=76
replace wkswka=7 if wkswk7688>=50 & wkswk7688<=52 & year>=76
/* Average weeks worked for each cell in 1976- */ 
replace wkswk7688=. if wkswk7688==0
egen wkswk7688avg=mean(wkswk7688), by(sex wkswka)
replace wkswk7688avg=round(wkswk7688avg,1)
gen wkswk=wkswk7688 if year>=76 /* Actual weeks 1975- */
replace wkswk=wkswk7688avg if year<=75 /* Imputed weeks before 1975 */
label var wkswk "Weeks of work (imputed for 1964-1975 surveys)"

*	IMPUTED AND ACTUAL HRS WORKED LAST WEEK

g byte fullpart=1 if ftpt==1 | ftpt==3
replace fullpart=2 if ftpt==2 | ftpt==4
/* Code: ftpt
                             62      63-67   68-75   76-01
NIU, children, armed forces          9       0       0
Full-time, full year         2       1       1       1
Part-time, full year         3       2       2       2
Full-time, part year         2       1       3       3
Part-time, part year         3       2       4       4
Nonworker                            9               5 */

/* Code: hours
                             62      63-67   68-93   94-01
NIU (non-interview)                          00      -1
Children and Armed Forces                    00      00
Hours                        01-99   01-98+  01-99+  01-99+
Not working or Armed Forces  100     99 */

replace hours=. if (hours==99 & year<=67) | hours<=0
egen hrsavg=mean(hours), by(year sex fullpart)

gen hrsweek=hrslyr if year>=76
/* 1964-75, hrs worked last week>0 */
replace hrsweek=hours if hrsweek==. & year<=75
/* 1964-75, hrs worked last week=0 */
replace hrsweek=hrsavg if hrsweek==. & year<=75

*	ANNUAL HRS WORKED

gen hrs=hrsweek*wkswk

drop wkswka wkswk6475 wkswk7688 wkswk7688avg 



*************************************************************************
*	RE-MAP JOBS INTO ONE COSISTENT CLASSIFICATION (1990)

replace year=year+1900
keep if year>=1968
replace occlyr=occlyr/10 if year>=2003 & year<=2006
rename occlyr ocsrc	/* remapjob.do needs this input */
g byte empstatd=0		/* remapjob.do needs this input */
compress
save tempcps6806, replace

local y=1968
while `y'<=2006 {
	clear
	use tempcps6806
	keep if year==`y'
	display "================ " `y' " ================"
	run remapjob_ariell.do
	#delimit cr
	save temp`y', replace
	local y=`y'+1
}

local y=1968
	clear
	use temp`y'
	erase temp`y'.dta
	local y=`y'+1
while `y'<=2006 {
	append using temp`y'
	erase temp`y'.dta
	local y=`y'+1
}

drop empstatd
sort year
save cps6806occ1990, replace
erase tempcps6806.dta



*************************************************************************
*	MERGE WITH DAVID AUTOR'S DOT SKILL DATA

clear
use dot77-occ1990n-gen
rename occ1990n ocdest
sort ocdest sex
save temp_dot77-occ1990n-gen, replace

clear
use cps6806occ1990

*	CORRECTIONS FROM David Dorn, MAINLY FOR SERVICES
replace ocdest=405 if ocdest==407
replace ocdest=444 if ocdest==438
replace ocdest=444 if ocdest==443
replace ocdest=447 if ocdest==446
replace ocdest=469 if ocdest==454
replace ocdest=275 if (ocdest>=263 & ocdest<=269)
replace ocdest=275 if ocdest==274
replace ocdest=319 if ocdest==323

*	MY CORRECTIONS, BASED ON OBSERVATIONS, MAINLY FOR SERVICES
replace ocdest=22 if ocdest==17 | ocdest==21

save cps6806occ1990, replace
sort ocdest sex
merge ocdest sex using temp_dot77-occ1990n-gen
erase temp_dot77-occ1990n-gen.dta
tab _merge
tab ocdest if _merge==2 
drop if _merge==2 /* these are all in public sector */

tab year _merge, r nofreq
tab ocsrc if _merge==1 & year>=1968 & year<=1970
tab ocsrc if _merge==1 & year>=1971 & year<=1982
tab ocsrc if _merge==1 & year>=1983 & year<=1991
tab ocsrc if _merge==1 & year>=1992 & year<=2002
tab ocsrc if _merge==1 & year>=2003 & year<=2006
tab ocdest if _merge==1
tab year ocdest if _merge==1
*drop if _merge==1
*drop _merge

rename ocdest occ
label var occ "census 1990 occupations"
order year ind2 indlyr occ wgt hrs age edu sex
sort year ind2 indlyr occ
keep occ hrs wgt ehf finger dcp sts math year ind2 indlyr edu sex age
save cps6806occupations_tasks, replace



*************************************************************************
*	CALCUALTE AVERAGES PER INDUSTRY*EDU*SEX CELL BY YEAR

replace ehf=ehf*hrs*wgt
replace finger=finger*hrs*wgt
replace dcp=dcp*hrs*wgt
replace sts=sts*hrs*wgt
replace math=math*hrs*wgt
replace hrs=hrs*wgt

collapse (sum) hrs ehf finger dcp sts math, by(year ind2 indlyr edu sex)

replace ehf=ehf/hrs
replace finger=finger/hrs
replace dcp=dcp/hrs
replace sts=sts/hrs
replace math=math/hrs

save cps6806dot_skills, replace


/***

*************************************************************************
*************************************************************************
*************************************************************************
*	CALCULATE DISTRIBUTION OVER INDUSTRY*EDU*SEX CELL FOR 1968 
*	THEN CALCULATE POSITION IN 1968 DISTRIBUTION FOR ALL OTHER YEARS

*	DONE THIS ONCE, NO NEED TO DO IT AGAIN: IT TAKES MORE THAN 10 HOURS

*	EYE-HAND-FOOT CORDINATION (ehf)

clear
use cps6806dot_skills
keep indlyr year ind2 sex edu hrs ehf
save cps6806dot_skills_temp, replace

keep if year==1968
sort ehf
egen pehf=pc(ehf) /* probailities */
g Pehf=sum(pehf)  /* percentiles */
drop pehf
qui sum year
local N1968=r(N)
local i=1
while `i'<=`N1968' {
	local ehf`i'=ehf[`i']
	local Pehf`i'=Pehf[`i']
	local i=`i'+1
}
save temp1968, replace

local ehf="ehf"
local Pehf="Pehf"

local y=1969
while `y'<=2006 {
	clear
	use cps6806dot_skills_temp
	keep if year==`y'
	sort ehf
	g Pehf=.
	qui sum year
	local N=r(N)
	local n=1
	while `n'<=`N' {
		local i=1
		while `i'<=`N1968' {
			qui replace P=``Pehf'`i'' if _n==`n' & ehf>=``ehf'`i''
			if (ehf[`n']<``ehf'`i'') local i=`N1968'
			local i=`i'+1
		}
		local n=`n'+1
	}
	save temp`y', replace
	local y=`y'+1
}

use temp1968
local y=1969
while `y'<=2006 {
	append using temp`y'
	erase temp`y'.dta
	local y=`y'+1
}

replace P=0 if P==.
save cps6806dot_skills_ehf, replace


*	FINGER DEXTERITY (finger)

clear
use cps6806dot_skills
keep indlyr year ind2 sex edu hrs finger
save cps6806dot_skills_temp, replace

keep if year==1968
sort finger
egen pfinger=pc(finger) /* probailities */
g Pfinger=sum(pfinger)  /* percentiles */
drop pfinger
qui sum year
local N1968=r(N)
local i=1
while `i'<=`N1968' {
	local finger`i'=finger[`i']
	local Pfinger`i'=Pfinger[`i']
	local i=`i'+1
}
save temp1968, replace

local finger="finger"
local Pfinger="Pfinger"

local y=1969
while `y'<=2006 {
	clear
	use cps6806dot_skills_temp
	keep if year==`y'
	sort finger
	g Pfinger=.
	qui sum year
	local N=r(N)
	local n=1
	while `n'<=`N' {
		local i=1
		while `i'<=`N1968' {
			qui replace P=``Pfinger'`i'' if _n==`n' & finger>=``finger'`i''
			if (finger[`n']<``finger'`i'') local i=`N1968'
			local i=`i'+1
		}
		local n=`n'+1
	}
	save temp`y', replace
	local y=`y'+1
}

use temp1968
local y=1969
while `y'<=2006 {
	append using temp`y'
	erase temp`y'.dta
	local y=`y'+1
}

replace P=0 if P==.
save cps6806dot_skills_finger, replace


*	DIRECTION CONTROL PLANNING (dcp)

clear
use cps6806dot_skills
keep indlyr year ind2 sex edu hrs dcp
save cps6806dot_skills_temp, replace

keep if year==1968
sort dcp
egen pdcp=pc(dcp) /* probailities */
g Pdcp=sum(pdcp)  /* percentiles */
drop pdcp
qui sum year
local N1968=r(N)
local i=1
while `i'<=`N1968' {
	local dcp`i'=dcp[`i']
	local Pdcp`i'=Pdcp[`i']
	local i=`i'+1
}
save temp1968, replace

local dcp="dcp"
local Pdcp="Pdcp"

local y=1969
while `y'<=2006 {
	clear
	use cps6806dot_skills_temp
	keep if year==`y'
	sort dcp
	g Pdcp=.
	qui sum year
	local N=r(N)
	local n=1
	while `n'<=`N' {
		local i=1
		while `i'<=`N1968' {
			qui replace P=``Pdcp'`i'' if _n==`n' & dcp>=``dcp'`i''
			if (dcp[`n']<``dcp'`i'') local i=`N1968'
			local i=`i'+1
		}
		local n=`n'+1
	}
	save temp`y', replace
	local y=`y'+1
}

use temp1968
local y=1969
while `y'<=2006 {
	append using temp`y'
	erase temp`y'.dta
	local y=`y'+1
}

replace P=0 if P==.
save cps6806dot_skills_dcp, replace


*	SET LIMIITS, TOLERANCES AND STANDARDS (sts)

clear
use cps6806dot_skills
keep indlyr year ind2 sex edu hrs sts
save cps6806dot_skills_temp, replace

keep if year==1968
sort sts
egen psts=pc(sts) /* probailities */
g Psts=sum(psts)  /* percentiles */
drop psts
qui sum year
local N1968=r(N)
local i=1
while `i'<=`N1968' {
	local sts`i'=sts[`i']
	local Psts`i'=Psts[`i']
	local i=`i'+1
}
save temp1968, replace

local sts="sts"
local Psts="Psts"

local y=1969
while `y'<=2006 {
	clear
	use cps6806dot_skills_temp
	keep if year==`y'
	sort sts
	g Psts=.
	qui sum year
	local N=r(N)
	local n=1
	while `n'<=`N' {
		local i=1
		while `i'<=`N1968' {
			qui replace P=``Psts'`i'' if _n==`n' & sts>=``sts'`i''
			if (sts[`n']<``sts'`i'') local i=`N1968'
			local i=`i'+1
		}
		local n=`n'+1
	}
	save temp`y', replace
	local y=`y'+1
}

use temp1968
local y=1969
while `y'<=2006 {
	append using temp`y'
	erase temp`y'.dta
	local y=`y'+1
}

replace P=0 if P==.
save cps6806dot_skills_sts, replace


*	MATH APTITUDE (math)

clear
use cps6806dot_skills
keep indlyr year ind2 sex edu hrs math
save cps6806dot_skills_temp, replace

keep if year==1968
sort math
egen pmath=pc(math) /* probailities */
g Pmath=sum(pmath)  /* percentiles */
drop pmath
qui sum year
local N1968=r(N)
local i=1
while `i'<=`N1968' {
	local math`i'=math[`i']
	local Pmath`i'=Pmath[`i']
	local i=`i'+1
}
save temp1968, replace

local math="math"
local Pmath="Pmath"

local y=1969
while `y'<=2006 {
	clear
	use cps6806dot_skills_temp
	keep if year==`y'
	sort math
	g Pmath=.
	qui sum year
	local N=r(N)
	local n=1
	while `n'<=`N' {
		local i=1
		while `i'<=`N1968' {
			qui replace P=``Pmath'`i'' if _n==`n' & math>=``math'`i''
			if (math[`n']<``math'`i'') local i=`N1968'
			local i=`i'+1
		}
		local n=`n'+1
	}
	save temp`y', replace
	local y=`y'+1
}

use temp1968
local y=1969
while `y'<=2006 {
	append using temp`y'
	erase temp`y'.dta
	local y=`y'+1
}

replace P=0 if P==.
save cps6806dot_skills_math, replace


*	MERGING

clear
use cps6806dot_skills_ehf
merge year ind2 indlyr sex edu using ///
	cps6806dot_skills_finger cps6806dot_skills_dcp ///
	cps6806dot_skills_sts cps6806dot_skills_math, sort
tab _merge
tab _merge1
tab _merge2
tab _merge3
tab _merge4
drop _merge*
replace year=year-1
label var year "data year (survey year-1)"
save cps6806dot_skills_distribution, replace

*************************************************************************
*************************************************************************
*************************************************************************

***/

***/

*************************************************************************
*************************************************************************
*************************************************************************

***	ALTERNATIVE TASK INTENSITY INDICES 

clear

*** base year to compare changes in index
local baseyear=1971



*************************************************************************
*	SECTOR AND EDUCATION
*	COLLEGE, HIGH-SCHOOL EQUIVALENTS

*	SERVICES

clear
use cps6806dot_skills_distribution
keep if ind2>=10
replace Pehf=Pehf*hrs
replace Pfinger=Pfinger*hrs
replace Pdcp=Pdcp*hrs
replace Psts=Psts*hrs
replace Pmath=Pmath*hrs

collapse (sum) hrs Pehf Pfinger Pdcp Psts Pmath, by(year edu)

replace Pehf=Pehf/hrs
replace Pfinger=Pfinger/hrs
replace Pdcp=Pdcp/hrs
replace Psts=Psts/hrs
replace Pmath=Pmath/hrs

reshape wide hrs Pehf Pfinger Pdcp Psts Pmath, i(year) j(edu)

*	equivalence weights from wage regressions
local e1hs=1.1115368
local e1col=-.15715299
local e3hs=.928918
local e3col=.13778953

*	1.752554 is the average college premium for the sample
local e1hs=`e1hs'+1.752554*`e1col'
local e1col=0

display `e1hs'
display `e1col'
display `e3hs'
display `e3col'

g hs = hrs2 + (`e1hs'*hrs1) + (`e3hs'*hrs3)
g col = hrs4 + (`e1col'*hrs1) + (`e3col'*hrs3)

g Pehf_hs = (hrs2*Pehf2 + (`e1hs'*hrs1*Pehf1) + (`e3hs'*hrs3*Pehf3))/hs
g Pehf_col = (hrs4*Pehf4 + (`e1col'*hrs1*Pehf1) + (`e3col'*hrs3*Pehf3))/col
g Pfinger_hs = (hrs2*Pfinger2 + (`e1hs'*hrs1*Pfinger1) + (`e3hs'*hrs3*Pfinger3))/hs
g Pfinger_col = (hrs4*Pfinger4 + (`e1col'*hrs1*Pfinger1) + (`e3col'*hrs3*Pfinger3))/col
g Pdcp_hs = (hrs2*Pdcp2 + (`e1hs'*hrs1*Pdcp1) + (`e3hs'*hrs3*Pdcp3))/hs
g Pdcp_col = (hrs4*Pdcp4 + (`e1col'*hrs1*Pdcp1) + (`e3col'*hrs3*Pdcp3))/col
g Psts_hs = (hrs2*Psts2 + (`e1hs'*hrs1*Psts1) + (`e3hs'*hrs3*Psts3))/hs
g Psts_col = (hrs4*Psts4 + (`e1col'*hrs1*Psts1) + (`e3col'*hrs3*Psts3))/col
g Pmath_hs = (hrs2*Pmath2 + (`e1hs'*hrs1*Pmath1) + (`e3hs'*hrs3*Pmath3))/hs
g Pmath_col = (hrs4*Pmath4 + (`e1col'*hrs1*Pmath1) + (`e3col'*hrs3*Pmath3))/col

keep year Pehf_hs Pfinger_hs Pdcp_hs Psts_hs Pmath_hs ///
	Pehf_col Pfinger_col Pdcp_col Psts_col Pmath_col


*	relative changes

g Dehf=(Pehf_hs-Pehf_hs[`baseyear'-1966]) - (Pehf_col-Pehf_col[`baseyear'-1966])
g Dfinger=(Pfinger_hs-Pfinger_hs[`baseyear'-1966]) - (Pfinger_col-Pfinger_col[`baseyear'-1966])
g Ddcp=(Pdcp_hs-Pdcp_hs[`baseyear'-1966]) - (Pdcp_col-Pdcp_col[`baseyear'-1966])
g Dsts=(Psts_hs-Psts_hs[`baseyear'-1966]) - (Psts_col-Psts_col[`baseyear'-1966])
g Dmath=(Pmath_hs-Pmath_hs[`baseyear'-1966]) - (Pmath_col-Pmath_col[`baseyear'-1966])


log using Table_6_7_occupation_task_index2, replace 

*
***	DATA USED TO CONSTRUCT TABLES 6 AND 7
*

*
***	FOR TABLE 7
*

*
***	SERVICES: HS v COLLEGE
*
list year Dehf-Dmath if year==2001, clean noobs

log close

label var Dehf "COORD"
label var Dfinger "DEX"
label var Ddcp "PLAN"
label var Dsts "STAND"
label var Dmath "MATH"
scatter Dmath Ddcp Dehf Dfinger Dsts year if year<=2001, ///
	title(B. Services) ///
	c(l l l l l) m(S T O Sh Dh) ///
	xtitle("") xlabel(1970(10)2000) ylabel(-.15(.05).1) scheme(s1color) ///
	lc (cranberry cranberry navy green green) ///
	mc (cranberry cranberry navy green green) ///
	legend(rows(2) size(small) region(margin(medsmall))) ///
	xline(`baseyear', lc(black) lp(-)) yline(0, lc(black))
graph save dot_skills_equivaents_serv_differences.gph, replace


*	GOODS

clear
use cps6806dot_skills_distribution
keep if ind2<=9
replace Pehf=Pehf*hrs
replace Pfinger=Pfinger*hrs
replace Pdcp=Pdcp*hrs
replace Psts=Psts*hrs
replace Pmath=Pmath*hrs

collapse (sum) hrs Pehf Pfinger Pdcp Psts Pmath, by(year edu)

replace Pehf=Pehf/hrs
replace Pfinger=Pfinger/hrs
replace Pdcp=Pdcp/hrs
replace Psts=Psts/hrs
replace Pmath=Pmath/hrs

reshape wide hrs Pehf Pfinger Pdcp Psts Pmath, i(year) j(edu)

*	equivalence weights from wage regressions
local e1hs=1.1115368
local e1col=-.15715299
local e3hs=.928918
local e3col=.13778953

*	1.752554 is the average college premium for the sample
local e1hs=`e1hs'+1.752554*`e1col'
local e1col=0

display `e1hs'
display `e1col'
display `e3hs'
display `e3col'

g hs = hrs2 + (`e1hs'*hrs1) + (`e3hs'*hrs3)
g col = hrs4 + (`e1col'*hrs1) + (`e3col'*hrs3)

g Pehf_hs = (hrs2*Pehf2 + (`e1hs'*hrs1*Pehf1) + (`e3hs'*hrs3*Pehf3))/hs
g Pehf_col = (hrs4*Pehf4 + (`e1col'*hrs1*Pehf1) + (`e3col'*hrs3*Pehf3))/col
g Pfinger_hs = (hrs2*Pfinger2 + (`e1hs'*hrs1*Pfinger1) + (`e3hs'*hrs3*Pfinger3))/hs
g Pfinger_col = (hrs4*Pfinger4 + (`e1col'*hrs1*Pfinger1) + (`e3col'*hrs3*Pfinger3))/col
g Pdcp_hs = (hrs2*Pdcp2 + (`e1hs'*hrs1*Pdcp1) + (`e3hs'*hrs3*Pdcp3))/hs
g Pdcp_col = (hrs4*Pdcp4 + (`e1col'*hrs1*Pdcp1) + (`e3col'*hrs3*Pdcp3))/col
g Psts_hs = (hrs2*Psts2 + (`e1hs'*hrs1*Psts1) + (`e3hs'*hrs3*Psts3))/hs
g Psts_col = (hrs4*Psts4 + (`e1col'*hrs1*Psts1) + (`e3col'*hrs3*Psts3))/col
g Pmath_hs = (hrs2*Pmath2 + (`e1hs'*hrs1*Pmath1) + (`e3hs'*hrs3*Pmath3))/hs
g Pmath_col = (hrs4*Pmath4 + (`e1col'*hrs1*Pmath1) + (`e3col'*hrs3*Pmath3))/col

keep year Pehf_hs Pfinger_hs Pdcp_hs Psts_hs Pmath_hs ///
	Pehf_col Pfinger_col Pdcp_col Psts_col Pmath_col


*	relative changes

g Dehf=(Pehf_hs-Pehf_hs[`baseyear'-1966]) - (Pehf_col-Pehf_col[`baseyear'-1966])
g Dfinger=(Pfinger_hs-Pfinger_hs[`baseyear'-1966]) - (Pfinger_col-Pfinger_col[`baseyear'-1966])
g Ddcp=(Pdcp_hs-Pdcp_hs[`baseyear'-1966]) - (Pdcp_col-Pdcp_col[`baseyear'-1966])
g Dsts=(Psts_hs-Psts_hs[`baseyear'-1966]) - (Psts_col-Psts_col[`baseyear'-1966])
g Dmath=(Pmath_hs-Pmath_hs[`baseyear'-1966]) - (Pmath_col-Pmath_col[`baseyear'-1966])


log using Table_6_7_occupation_task_index2, append

*
***	GOODS: HS v COLLEGE
*
list year Dehf-Dmath if year==2001, clean noobs

log close


label var Dehf "COORD"
label var Dfinger "DEX"
label var Ddcp "PLAN"
label var Dsts "STAND"
label var Dmath "MATH"
scatter Dmath Ddcp Dehf Dfinger Dsts year if year<=2001, ///
	title(A. Goods) ///
	c(l l l l l) m(S T O Sh Dh) ///
	xtitle("") xlabel(1970(10)2000) ylabel(-.15(.05).1) scheme(s1color) ///
	lc (cranberry cranberry navy green green) ///
	mc (cranberry cranberry navy green green) ///
	legend(rows(2) size(small) region(margin(medsmall))) ///
	xline(`baseyear', lc(black) lp(-)) yline(0, lc(black))
graph save dot_skills_equivaents_good_differences.gph, replace



***	COMBINE GOODS AND SERVICES DIFFERENCES FIGURES

graph combine dot_skills_equivaents_good_differences.gph ///
	dot_skills_equivaents_serv_differences.gph, ///
	ycom xcom scheme(s1color)
graph save   Figure6_dot_skills_equivaents_differences_Pdiff, replace
graph export Figure6_dot_skills_equivaents_differences_Pdiff.wmf, as(wmf) replace
graph export Figure6_dot_skills_equivaents_differences_Pdiff.eps, as(eps) replace

erase dot_skills_equivaents_good_differences.gph
erase dot_skills_equivaents_serv_differences.gph



*	HIGH SCHOOL EQUIVALENTS IN SERVICES VERSUS GOODS

*	SERVICES

clear
use cps6806dot_skills_distribution
keep if ind2>=10
replace Pehf=Pehf*hrs
replace Pfinger=Pfinger*hrs
replace Pdcp=Pdcp*hrs
replace Psts=Psts*hrs
replace Pmath=Pmath*hrs

collapse (sum) hrs Pehf Pfinger Pdcp Psts Pmath, by(year edu)

replace Pehf=Pehf/hrs
replace Pfinger=Pfinger/hrs
replace Pdcp=Pdcp/hrs
replace Psts=Psts/hrs
replace Pmath=Pmath/hrs

reshape wide hrs Pehf Pfinger Pdcp Psts Pmath, i(year) j(edu)

*	equivalence weights from wage regressions
local e1hs=1.1115368
local e1col=-.15715299
local e3hs=.928918
local e3col=.13778953

*	1.752554 is the average college premium for the sample
local e1hs=`e1hs'+1.752554*`e1col'
local e1col=0

display `e1hs'
display `e1col'
display `e3hs'
display `e3col'

g hs = hrs2 + (`e1hs'*hrs1) + (`e3hs'*hrs3)
g col = hrs4 + (`e1col'*hrs1) + (`e3col'*hrs3)

g Pehf_hs2 = (hrs2*Pehf2 + (`e1hs'*hrs1*Pehf1) + (`e3hs'*hrs3*Pehf3))/hs
g Pehf_col2 = (hrs4*Pehf4 + (`e1col'*hrs1*Pehf1) + (`e3col'*hrs3*Pehf3))/col
g Pfinger_hs2 = (hrs2*Pfinger2 + (`e1hs'*hrs1*Pfinger1) + (`e3hs'*hrs3*Pfinger3))/hs
g Pfinger_col2 = (hrs4*Pfinger4 + (`e1col'*hrs1*Pfinger1) + (`e3col'*hrs3*Pfinger3))/col
g Pdcp_hs2 = (hrs2*Pdcp2 + (`e1hs'*hrs1*Pdcp1) + (`e3hs'*hrs3*Pdcp3))/hs
g Pdcp_col2 = (hrs4*Pdcp4 + (`e1col'*hrs1*Pdcp1) + (`e3col'*hrs3*Pdcp3))/col
g Psts_hs2 = (hrs2*Psts2 + (`e1hs'*hrs1*Psts1) + (`e3hs'*hrs3*Psts3))/hs
g Psts_col2 = (hrs4*Psts4 + (`e1col'*hrs1*Psts1) + (`e3col'*hrs3*Psts3))/col
g Pmath_hs2 = (hrs2*Pmath2 + (`e1hs'*hrs1*Pmath1) + (`e3hs'*hrs3*Pmath3))/hs
g Pmath_col2 = (hrs4*Pmath4 + (`e1col'*hrs1*Pmath1) + (`e3col'*hrs3*Pmath3))/col

keep year P*_hs2 P*_col2
sort year
save temp2, replace


*	GOODS

clear
use cps6806dot_skills_distribution
keep if ind2<=9
replace Pehf=Pehf*hrs
replace Pfinger=Pfinger*hrs
replace Pdcp=Pdcp*hrs
replace Psts=Psts*hrs
replace Pmath=Pmath*hrs

collapse (sum) hrs Pehf Pfinger Pdcp Psts Pmath, by(year edu)

replace Pehf=Pehf/hrs
replace Pfinger=Pfinger/hrs
replace Pdcp=Pdcp/hrs
replace Psts=Psts/hrs
replace Pmath=Pmath/hrs

reshape wide hrs Pehf Pfinger Pdcp Psts Pmath, i(year) j(edu)

*	equivalence weights from wage regressions
local e1hs=1.1115368
local e1col=-.15715299
local e3hs=.928918
local e3col=.13778953

*	1.752554 is the average college premium for the sample
local e1hs=`e1hs'+1.752554*`e1col'
local e1col=0

display `e1hs'
display `e1col'
display `e3hs'
display `e3col'

g hs = hrs2 + (`e1hs'*hrs1) + (`e3hs'*hrs3)
g col = hrs4 + (`e1col'*hrs1) + (`e3col'*hrs3)

g Pehf_hs1 = (hrs2*Pehf2 + (`e1hs'*hrs1*Pehf1) + (`e3hs'*hrs3*Pehf3))/hs
g Pehf_col1 = (hrs4*Pehf4 + (`e1col'*hrs1*Pehf1) + (`e3col'*hrs3*Pehf3))/col
g Pfinger_hs1 = (hrs2*Pfinger2 + (`e1hs'*hrs1*Pfinger1) + (`e3hs'*hrs3*Pfinger3))/hs
g Pfinger_col1 = (hrs4*Pfinger4 + (`e1col'*hrs1*Pfinger1) + (`e3col'*hrs3*Pfinger3))/col
g Pdcp_hs1 = (hrs2*Pdcp2 + (`e1hs'*hrs1*Pdcp1) + (`e3hs'*hrs3*Pdcp3))/hs
g Pdcp_col1 = (hrs4*Pdcp4 + (`e1col'*hrs1*Pdcp1) + (`e3col'*hrs3*Pdcp3))/col
g Psts_hs1 = (hrs2*Psts2 + (`e1hs'*hrs1*Psts1) + (`e3hs'*hrs3*Psts3))/hs
g Psts_col1 = (hrs4*Psts4 + (`e1col'*hrs1*Psts1) + (`e3col'*hrs3*Psts3))/col
g Pmath_hs1 = (hrs2*Pmath2 + (`e1hs'*hrs1*Pmath1) + (`e3hs'*hrs3*Pmath3))/hs
g Pmath_col1 = (hrs4*Pmath4 + (`e1col'*hrs1*Pmath1) + (`e3col'*hrs3*Pmath3))/col

keep year P*_hs1 P*_col1

sort year
merge year using temp2, sort
tab _m
drop _m
erase temp2.dta


*	relative changes

g Dehf_hs=(Pehf_hs2-Pehf_hs2[`baseyear'-1966]) - (Pehf_hs1-Pehf_hs1[`baseyear'-1966])
g Dfinger_hs=(Pfinger_hs2-Pfinger_hs2[`baseyear'-1966]) - (Pfinger_hs1-Pfinger_hs1[`baseyear'-1966])
g Ddcp_hs=(Pdcp_hs2-Pdcp_hs2[`baseyear'-1966]) - (Pdcp_hs1-Pdcp_hs1[`baseyear'-1966])
g Dsts_hs=(Psts_hs2-Psts_hs2[`baseyear'-1966]) - (Psts_hs1-Psts_hs1[`baseyear'-1966])
g Dmath_hs=(Pmath_hs2-Pmath_hs2[`baseyear'-1966]) - (Pmath_hs1-Pmath_hs1[`baseyear'-1966])

g Dehf_col=(Pehf_col2-Pehf_col2[`baseyear'-1966]) - (Pehf_col1-Pehf_col1[`baseyear'-1966])
g Dfinger_col=(Pfinger_col2-Pfinger_col2[`baseyear'-1966]) - (Pfinger_col1-Pfinger_col1[`baseyear'-1966])
g Ddcp_col=(Pdcp_col2-Pdcp_col2[`baseyear'-1966]) - (Pdcp_col1-Pdcp_col1[`baseyear'-1966])
g Dsts_col=(Psts_col2-Psts_col2[`baseyear'-1966]) - (Psts_col1-Psts_col1[`baseyear'-1966])
g Dmath_col=(Pmath_col2-Pmath_col2[`baseyear'-1966]) - (Pmath_col1-Pmath_col1[`baseyear'-1966])


label var Dehf_hs "COORD"
label var Dfinger_hs "DEX"
label var Ddcp_hs "PLAN"
label var Dsts_hs "STAND"
label var Dmath_hs "MATH"

/***
scatter Dmath_hs Ddcp_hs Dehf_hs Dfinger_hs Dsts_hs year if year<=2001, ///
	ti(High School Equivalents: Services versus Goods) ///
	c(l l l l l) m(S T O Sh Dh) ///
	xtitle("") xlabel(1970(10)2000) ylabel(-.05(.025).05) scheme(s1color) ///
	lc (cranberry cranberry navy green green) ///
	mc (cranberry cranberry navy green green) ///
	legend(rows(2) size(small) region(margin(medsmall))) ///
	xline(1971 `baseyear', lc(black) lp(-)) yline(0, lc(black))
graph export dot_skills_equivaents_hs_differences.wmf, as(wmf) replace
graph save   dot_skills_equivaents_hs_differences.gph, replace
***/

log using Table_6_7_occupation_task_index2, append
*
***	HS: SERVICES v GOODS
*
list year Dehf_hs-Dmath_hs if year==2001, clean noobs
*
***	COLLEGE: SERVICES v GOODS
*
list year Dehf_col-Dmath_col if year==2001, clean noobs
log close



compress
sort year
note: prepared by occupation_task_index2.do
note: 1=goods, 2=services
save cps6806dot_hs_col_equivalents, replace

*************************************************************************



*************************************************************************
***	TASK INDICES BY SECTOR AND EDUCATION LABOR EQUIVALENT

use cps6806dot_hs_col_equivalents, clear

/***

label var Pehf_col1 "COORD"
label var Pehf_col2 "COORD"
label var Pehf_hs1 "COORD"
label var Pehf_hs2 "COORD"

label var Pfinger_col1 "DEX"
label var Pfinger_col2 "DEX"
label var Pfinger_hs1 "DEX"
label var Pfinger_hs2 "DEX"

label var Pdcp_col1 "PLAN"
label var Pdcp_col2 "PLAN"
label var Pdcp_hs1 "PLAN"
label var Pdcp_hs2 "PLAN"

label var Psts_col1 "STAND"
label var Psts_col2 "STAND"
label var Psts_hs1 "STAND"
label var Psts_hs2 "STAND"

label var Pmath_col1 "MATH"
label var Pmath_col2 "MATH"
label var Pmath_hs1 "MATH"
label var Pmath_hs2 "MATH"


scatter Pmath_hs1 Pdcp_hs1 Pehf_hs1 Pfinger_hs1 Psts_hs1 year if year<=2001, ///
	c(l l l l l) m(S T O Sh Dh) ti("A. Goods, High School", size(medium)) ///
	xtitle("") xlabel(1970(10)2000) ylabel(.35(.05).7) ///
	lc (cranberry cranberry navy green green) ///
	mc (cranberry cranberry navy green green) ///
	legend(rows(2) size(small) region(margin(medsmall))) xsize(4) ysize(3)
graph export dot_good_hs.wmf, as(wmf) replace
graph save   dot_good_hs, replace

scatter Pmath_col1 Pdcp_col1 Pehf_col1 Pfinger_col1 Psts_col1 year if year<=2001, ///
	c(l l l l l) m(S T O Sh Dh) ti("C. Goods, College", size(medium)) ///
	xtitle("") xlabel(1970(10)2000) ylabel(.1(.1).9) ///
	lc (cranberry cranberry navy green green) ///
	mc (cranberry cranberry navy green green) ///
	legend(rows(2) size(small) region(margin(medsmall))) xsize(4) ysize(3)
graph export dot_good_col.wmf, as(wmf) replace
graph save   dot_good_col, replace

scatter Pmath_hs2 Pdcp_hs2 Pehf_hs2 Pfinger_hs2 Psts_hs2 year if year<=2001, ///
	c(l l l l l) m(S T O Sh Dh) ti("B. Services, High School", size(medium)) ///
	xtitle("") xlabel(1970(10)2000) ylabel(.35(.05).7) ///
	lc (cranberry cranberry navy green green) ///
	mc (cranberry cranberry navy green green) ///
	legend(rows(2) size(small) region(margin(medsmall))) xsize(4) ysize(3)
graph export dot_serv_hs.wmf, as(wmf) replace
graph save   dot_serv_hs, replace

scatter Pmath_col2 Pdcp_col2 Pehf_col2 Pfinger_col2 Psts_col2 year if year<=2001, ///
	c(l l l l l) m(S T O Sh Dh) ti("D. Services, College", size(medium)) ///
	xtitle("") xlabel(1970(10)2000) ylabel(.1(.1).9) ///
	lc (cranberry cranberry navy green green) ///
	mc (cranberry cranberry navy green green) ///
	legend(rows(2) size(small) region(margin(medsmall))) xsize(4) ysize(3)
graph export dot_serv_col.wmf, as(wmf) replace
graph save   dot_serv_col, replace

graph combine dot_good_hs.gph dot_serv_hs.gph dot_good_col.gph dot_serv_col.gph ///
	, xsize(4) ysize(6)
graph export dot_all.wmf, as(wmf) replace
graph save   dot_all, replace

erase dot_good_hs.gph 
erase dot_serv_hs.gph 
erase dot_good_col.gph 
erase dot_serv_col.gph 

***/


log using Table_6_7_occupation_task_index2, append

*
***	FOR TABLE 6
*

*
***	HS: GOODS
*
list year Pfinger_hs1 Psts_hs1 Pehf_hs1 Pmath_hs1 Pdcp_hs1 if year==1971 | year==2001, clean noobs
*
***	HS: SERVICES
*
list year Pfinger_hs2 Psts_hs2 Pehf_hs2 Pmath_hs2 Pdcp_hs2 if year==1971 | year==2001, clean noobs
*
***	COLLEGE: GOODS
*
list year Pfinger_col1 Psts_col1 Pehf_col1 Pmath_col1 Pdcp_col1 if year==1971 | year==2001, clean noobs
*
***	COLLEGE: SERVICES
*
list year Pfinger_col2 Psts_col2 Pehf_col2 Pmath_col2 Pdcp_col2 if year==1971 | year==2001, clean noobs
*
log close

*************************************************************************
